@@ -2,7 +2,7 @@
 ! Programmer(s): Daniel R. Reynolds @ SMU
 ! ------------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -17,14 +17,14 @@
 module fnvector_complex_mod
 
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+  use fsundials_core_mod
 
   implicit none
 
   ! ----------------------------------------------------------------
   type, public :: FVec
     logical                            :: own_data
-    integer(c_long)                    :: len
+    integer(c_int64_t)                    :: len
     complex(c_double_complex), pointer :: data(:)
   end type FVec
   ! ----------------------------------------------------------------
@@ -35,18 +35,18 @@ contains
   function FN_VNew_Complex(n, sunctx) result(sunvec_y)
 
     implicit none
-    integer(c_long),    value   :: n
-    type(c_ptr),        value   :: sunctx
-    type(N_Vector),     pointer :: sunvec_y
+    integer(c_int64_t), value   :: n
+    type(c_ptr), value   :: sunctx
+    type(N_Vector), pointer :: sunvec_y
     type(N_Vector_Ops), pointer :: ops
-    type(FVec),         pointer :: content
+    type(FVec), pointer :: content
 
     ! allocate output N_Vector structure
     sunvec_y => FN_VNewEmpty(sunctx)
 
     ! allocate and fill content structure
-    allocate(content)
-    allocate(content%data(n))
+    allocate (content)
+    allocate (content%data(n))
     content%own_data = .true.
     content%len = n
 
@@ -55,31 +55,31 @@ contains
 
     ! access the N_Vector ops structure, and set internal function pointers
     call c_f_pointer(sunvec_y%ops, ops)
-    ops%nvgetvectorid      = c_funloc(FN_VGetVectorID_Complex)
-    ops%nvdestroy          = c_funloc(FN_VDestroy_Complex)
-    ops%nvgetlength        = c_funloc(FN_VGetLength_Complex)
-    ops%nvconst            = c_funloc(FN_VConst_Complex)
-    ops%nvclone            = c_funloc(FN_VClone_Complex)
-    ops%nvspace            = c_funloc(FN_VSpace_Complex)
-    ops%nvlinearsum        = c_funloc(FN_VLinearSum_Complex)
-    ops%nvprod             = c_funloc(FN_VProd_Complex)
-    ops%nvdiv              = c_funloc(FN_VDiv_Complex)
-    ops%nvscale            = c_funloc(FN_VScale_Complex)
-    ops%nvabs              = c_funloc(FN_VAbs_Complex)
-    ops%nvinv              = c_funloc(FN_VInv_Complex)
-    ops%nvaddconst         = c_funloc(FN_VAddConst_Complex)
-    ops%nvmaxnorm          = c_funloc(FN_VMaxNorm_Complex)
-    ops%nvwrmsnorm         = c_funloc(FN_VWRMSNorm_Complex)
-    ops%nvwrmsnormmask     = c_funloc(FN_VWRMSNormMask_Complex)
-    ops%nvmin              = c_funloc(FN_VMin_Complex)
-    ops%nvwl2norm          = c_funloc(FN_VWL2Norm_Complex)
-    ops%nvl1norm           = c_funloc(FN_VL1Norm_Complex)
-    ops%nvinvtest          = c_funloc(FN_VInvTest_Complex)
-    ops%nvmaxnormlocal     = c_funloc(FN_VMaxNorm_Complex)
-    ops%nvminlocal         = c_funloc(FN_VMin_Complex)
-    ops%nvl1normlocal      = c_funloc(FN_VL1Norm_Complex)
-    ops%nvinvtestlocal     = c_funloc(FN_VInvTest_Complex)
-    ops%nvwsqrsumlocal     = c_funloc(FN_VWSqrSum_Complex)
+    ops%nvgetvectorid = c_funloc(FN_VGetVectorID_Complex)
+    ops%nvdestroy = c_funloc(FN_VDestroy_Complex)
+    ops%nvgetlength = c_funloc(FN_VGetLength_Complex)
+    ops%nvconst = c_funloc(FN_VConst_Complex)
+    ops%nvclone = c_funloc(FN_VClone_Complex)
+    ops%nvspace = c_funloc(FN_VSpace_Complex)
+    ops%nvlinearsum = c_funloc(FN_VLinearSum_Complex)
+    ops%nvprod = c_funloc(FN_VProd_Complex)
+    ops%nvdiv = c_funloc(FN_VDiv_Complex)
+    ops%nvscale = c_funloc(FN_VScale_Complex)
+    ops%nvabs = c_funloc(FN_VAbs_Complex)
+    ops%nvinv = c_funloc(FN_VInv_Complex)
+    ops%nvaddconst = c_funloc(FN_VAddConst_Complex)
+    ops%nvmaxnorm = c_funloc(FN_VMaxNorm_Complex)
+    ops%nvwrmsnorm = c_funloc(FN_VWRMSNorm_Complex)
+    ops%nvwrmsnormmask = c_funloc(FN_VWRMSNormMask_Complex)
+    ops%nvmin = c_funloc(FN_VMin_Complex)
+    ops%nvwl2norm = c_funloc(FN_VWL2Norm_Complex)
+    ops%nvl1norm = c_funloc(FN_VL1Norm_Complex)
+    ops%nvinvtest = c_funloc(FN_VInvTest_Complex)
+    ops%nvmaxnormlocal = c_funloc(FN_VMaxNorm_Complex)
+    ops%nvminlocal = c_funloc(FN_VMin_Complex)
+    ops%nvl1normlocal = c_funloc(FN_VL1Norm_Complex)
+    ops%nvinvtestlocal = c_funloc(FN_VInvTest_Complex)
+    ops%nvwsqrsumlocal = c_funloc(FN_VWSqrSum_Complex)
     ops%nvwsqrsummasklocal = c_funloc(FN_VWSqrSumMask_Complex)
 
   end function FN_VNew_Complex
@@ -88,18 +88,18 @@ contains
   function FN_VMake_Complex(n, data, sunctx) result(sunvec_y)
 
     implicit none
-    integer(c_long),           value   :: n
-    type(c_ptr),               value   :: sunctx
-    type(N_Vector),            pointer :: sunvec_y
-    type(N_Vector_Ops),        pointer :: ops
-    type(FVec),                pointer :: content
+    integer(c_int64_t), value   :: n
+    type(c_ptr), value   :: sunctx
+    type(N_Vector), pointer :: sunvec_y
+    type(N_Vector_Ops), pointer :: ops
+    type(FVec), pointer :: content
     complex(c_double_complex), target  :: data(:)
 
     ! allocate output N_Vector structure
     sunvec_y => FN_VNewEmpty(sunctx)
 
     ! allocate and fill content structure
-    allocate(content)
+    allocate (content)
     content%own_data = .false.
     content%len = n
     content%data => data
@@ -109,31 +109,31 @@ contains
 
     ! access the N_Vector ops structure, and set internal function pointers
     call c_f_pointer(sunvec_y%ops, ops)
-    ops%nvgetvectorid      = c_funloc(FN_VGetVectorID_Complex)
-    ops%nvdestroy          = c_funloc(FN_VDestroy_Complex)
-    ops%nvgetlength        = c_funloc(FN_VGetLength_Complex)
-    ops%nvconst            = c_funloc(FN_VConst_Complex)
-    ops%nvclone            = c_funloc(FN_VClone_Complex)
-    ops%nvspace            = c_funloc(FN_VSpace_Complex)
-    ops%nvlinearsum        = c_funloc(FN_VLinearSum_Complex)
-    ops%nvprod             = c_funloc(FN_VProd_Complex)
-    ops%nvdiv              = c_funloc(FN_VDiv_Complex)
-    ops%nvscale            = c_funloc(FN_VScale_Complex)
-    ops%nvabs              = c_funloc(FN_VAbs_Complex)
-    ops%nvinv              = c_funloc(FN_VInv_Complex)
-    ops%nvaddconst         = c_funloc(FN_VAddConst_Complex)
-    ops%nvmaxnorm          = c_funloc(FN_VMaxNorm_Complex)
-    ops%nvwrmsnorm         = c_funloc(FN_VWRMSNorm_Complex)
-    ops%nvwrmsnormmask     = c_funloc(FN_VWRMSNormMask_Complex)
-    ops%nvmin              = c_funloc(FN_VMin_Complex)
-    ops%nvwl2norm          = c_funloc(FN_VWL2Norm_Complex)
-    ops%nvl1norm           = c_funloc(FN_VL1Norm_Complex)
-    ops%nvinvtest          = c_funloc(FN_VInvTest_Complex)
-    ops%nvmaxnormlocal     = c_funloc(FN_VMaxNorm_Complex)
-    ops%nvminlocal         = c_funloc(FN_VMin_Complex)
-    ops%nvl1normlocal      = c_funloc(FN_VL1Norm_Complex)
-    ops%nvinvtestlocal     = c_funloc(FN_VInvTest_Complex)
-    ops%nvwsqrsumlocal     = c_funloc(FN_VWSqrSum_Complex)
+    ops%nvgetvectorid = c_funloc(FN_VGetVectorID_Complex)
+    ops%nvdestroy = c_funloc(FN_VDestroy_Complex)
+    ops%nvgetlength = c_funloc(FN_VGetLength_Complex)
+    ops%nvconst = c_funloc(FN_VConst_Complex)
+    ops%nvclone = c_funloc(FN_VClone_Complex)
+    ops%nvspace = c_funloc(FN_VSpace_Complex)
+    ops%nvlinearsum = c_funloc(FN_VLinearSum_Complex)
+    ops%nvprod = c_funloc(FN_VProd_Complex)
+    ops%nvdiv = c_funloc(FN_VDiv_Complex)
+    ops%nvscale = c_funloc(FN_VScale_Complex)
+    ops%nvabs = c_funloc(FN_VAbs_Complex)
+    ops%nvinv = c_funloc(FN_VInv_Complex)
+    ops%nvaddconst = c_funloc(FN_VAddConst_Complex)
+    ops%nvmaxnorm = c_funloc(FN_VMaxNorm_Complex)
+    ops%nvwrmsnorm = c_funloc(FN_VWRMSNorm_Complex)
+    ops%nvwrmsnormmask = c_funloc(FN_VWRMSNormMask_Complex)
+    ops%nvmin = c_funloc(FN_VMin_Complex)
+    ops%nvwl2norm = c_funloc(FN_VWL2Norm_Complex)
+    ops%nvl1norm = c_funloc(FN_VL1Norm_Complex)
+    ops%nvinvtest = c_funloc(FN_VInvTest_Complex)
+    ops%nvmaxnormlocal = c_funloc(FN_VMaxNorm_Complex)
+    ops%nvminlocal = c_funloc(FN_VMin_Complex)
+    ops%nvl1normlocal = c_funloc(FN_VL1Norm_Complex)
+    ops%nvinvtestlocal = c_funloc(FN_VInvTest_Complex)
+    ops%nvwsqrsumlocal = c_funloc(FN_VWSqrSum_Complex)
     ops%nvwsqrsummasklocal = c_funloc(FN_VWSqrSumMask_Complex)
 
   end function FN_VMake_Complex
@@ -169,16 +169,16 @@ contains
 
     implicit none
     type(N_Vector), target  :: sunvec_y
-    type(FVec),     pointer :: y
+    type(FVec), pointer :: y
 
     ! access FVec structure
     y => FN_VGetFVec(sunvec_y)
 
     ! if vector owns the data, then deallocate
-    if (y%own_data)  deallocate(y%data)
+    if (y%own_data) deallocate (y%data)
 
     ! deallocate the underlying Fortran object (the content)
-    deallocate(y)
+    deallocate (y)
 
     ! set N_Vector structure members to NULL and return
     sunvec_y%content = C_NULL_PTR
@@ -191,12 +191,12 @@ contains
   end subroutine FN_VDestroy_Complex
 
   ! ----------------------------------------------------------------
-  integer(c_long) function FN_VGetLength_Complex(sunvec_y) &
-      bind(C) result(length)
+  integer(c_int64_t) function FN_VGetLength_Complex(sunvec_y) &
+    bind(C) result(length)
 
     implicit none
     type(N_Vector)         :: sunvec_y
-    type(FVec),    pointer :: y
+    type(FVec), pointer :: y
 
     y => FN_VGetFVec(sunvec_y)
     length = y%len
@@ -210,7 +210,7 @@ contains
     implicit none
     type(N_Vector)          :: sunvec_y
     real(c_double), value   :: const
-    type(FVec),     pointer :: y
+    type(FVec), pointer :: y
 
     ! extract Fortran vector structure to work with
     y => FN_VGetFVec(sunvec_y)
@@ -229,7 +229,7 @@ contains
     type(N_Vector), pointer :: sunvec_y
     type(c_ptr)             :: y_ptr
     integer(c_int)          :: retval
-    type(FVec),     pointer :: x, y
+    type(FVec), pointer :: x, y
 
     ! extract Fortran vector structure to work with
     x => FN_VGetFVec(sunvec_x)
@@ -241,8 +241,8 @@ contains
     retval = FN_VCopyOps(sunvec_x, sunvec_y)
 
     ! allocate and clone content structure
-    allocate(y)
-    allocate(y%data(x%len))
+    allocate (y)
+    allocate (y%data(x%len))
     y%own_data = .true.
     y%len = x%len
 
@@ -276,7 +276,7 @@ contains
 
   ! ----------------------------------------------------------------
   subroutine FN_VLinearSum_Complex(a, sunvec_x, b, sunvec_y, sunvec_z) &
-       bind(C)
+    bind(C)
 
     implicit none
     type(N_Vector)          :: sunvec_x
@@ -284,7 +284,7 @@ contains
     type(N_Vector)          :: sunvec_z
     real(c_double), value   :: a
     real(c_double), value   :: b
-    type(FVec),     pointer :: x, y, z
+    type(FVec), pointer :: x, y, z
 
     ! extract Fortran vector structures to work with
     x => FN_VGetFVec(sunvec_x)
@@ -312,7 +312,7 @@ contains
     z => FN_VGetFVec(sunvec_z)
 
     ! perform computation (via whole array ops) and return
-    z%data = x%data * y%data
+    z%data = x%data*y%data
     return
 
   end subroutine FN_VProd_Complex
@@ -332,7 +332,7 @@ contains
     z => FN_VGetFVec(sunvec_z)
 
     ! perform computation (via whole array ops) and return
-    z%data = x%data / y%data
+    z%data = x%data/y%data
     return
 
   end subroutine FN_VDiv_Complex
@@ -344,14 +344,14 @@ contains
     real(c_double), value   :: c
     type(N_Vector)          :: sunvec_x
     type(N_Vector)          :: sunvec_z
-    type(FVec),     pointer :: x, z
+    type(FVec), pointer :: x, z
 
     ! extract Fortran vector structures to work with
     x => FN_VGetFVec(sunvec_x)
     z => FN_VGetFVec(sunvec_z)
 
     ! perform computation (via whole array ops) and return
-    z%data = c * x%data
+    z%data = c*x%data
     return
 
   end subroutine FN_VScale_Complex
@@ -387,7 +387,7 @@ contains
     z => FN_VGetFVec(sunvec_z)
 
     ! perform computation (via whole array ops) and return
-    z%data = 1.d0 / x%data
+    z%data = 1.d0/x%data
     return
 
   end subroutine FN_VInv_Complex
@@ -399,7 +399,7 @@ contains
     type(N_Vector)          :: sunvec_x
     real(c_double), value   :: b
     type(N_Vector)          :: sunvec_z
-    type(FVec),     pointer :: x, z
+    type(FVec), pointer :: x, z
 
     ! extract Fortran vector structures to work with
     x => FN_VGetFVec(sunvec_x)
@@ -413,7 +413,7 @@ contains
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VMaxNorm_Complex(sunvec_x) &
-       result(maxnorm) bind(C)
+    result(maxnorm) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -430,7 +430,7 @@ contains
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VWSqrSum_Complex(sunvec_x, sunvec_w) &
-       result(sqrsum) bind(C)
+    result(sqrsum) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -442,21 +442,21 @@ contains
     w => FN_VGetFVec(sunvec_w)
 
     ! perform computation (via whole array ops) and return
-    sqrsum = sum(abs(x%data)**2 * abs(w%data)**2)
+    sqrsum = sum(abs(x%data)**2*abs(w%data)**2)
     return
 
   end function FN_VWSqrSum_Complex
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VWSqrSumMask_Complex(sunvec_x, sunvec_w, sunvec_id) &
-       result(sqrsum) bind(C)
+    result(sqrsum) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
     type(N_Vector)      :: sunvec_w
     type(N_Vector)      :: sunvec_id
     type(FVec), pointer :: x, w, id
-    integer(c_long)     :: i
+    integer(c_int64_t)     :: i
 
     ! extract Fortran vector structures to work with
     x => FN_VGetFVec(sunvec_x)
@@ -465,10 +465,10 @@ contains
 
     ! perform computation and return
     sqrsum = 0.d0
-    do i = 1,x%len
-       if (real(id%data(i)) > 0.d0) then
-          sqrsum = sqrsum + (abs(x%data(i)) * abs(w%data(i)))**2
-       end if
+    do i = 1, x%len
+      if (real(id%data(i)) > 0.d0) then
+        sqrsum = sqrsum + (abs(x%data(i))*abs(w%data(i)))**2
+      end if
     end do
     return
 
@@ -476,7 +476,7 @@ contains
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VWRMSNorm_Complex(sunvec_x, sunvec_w) &
-       result(wrmsnorm) bind(C)
+    result(wrmsnorm) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -487,15 +487,14 @@ contains
     x => FN_VGetFVec(sunvec_x)
 
     ! postprocess result from FN_VWSqrSum for result
-    wrmsnorm = dsqrt( FN_VWSqrSum_Complex(sunvec_x, sunvec_w) / x%len )
+    wrmsnorm = dsqrt(FN_VWSqrSum_Complex(sunvec_x, sunvec_w)/x%len)
     return
 
   end function FN_VWRMSNorm_Complex
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VWRMSNormMask_Complex(sunvec_x, sunvec_w, sunvec_id) &
-       result(wrmsnorm) bind(C)
-
+    result(wrmsnorm) bind(C)
     implicit none
     type(N_Vector)      :: sunvec_x
     type(N_Vector)      :: sunvec_w
@@ -506,14 +505,14 @@ contains
     x => FN_VGetFVec(sunvec_x)
 
     ! postprocess result from FN_VWSqrSumMask for result
-    wrmsnorm = dsqrt( FN_VWSqrSumMask_Complex(sunvec_x, sunvec_w, sunvec_id) / x%len )
+    wrmsnorm = dsqrt(FN_VWSqrSumMask_Complex(sunvec_x, sunvec_w, sunvec_id)/x%len)
     return
 
   end function FN_VWRMSNormMask_Complex
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VMin_Complex(sunvec_x) &
-       result(mnval) bind(C)
+    result(mnval) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -531,7 +530,7 @@ contains
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VWL2Norm_Complex(sunvec_x, sunvec_w) &
-       result(wl2norm) bind(C)
+    result(wl2norm) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -549,7 +548,7 @@ contains
 
   ! ----------------------------------------------------------------
   real(c_double) function FN_VL1Norm_Complex(sunvec_x) &
-       result(l1norm) bind(C)
+    result(l1norm) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
@@ -566,13 +565,13 @@ contains
 
   ! ----------------------------------------------------------------
   integer(c_int) function FN_VInvTest_Complex(sunvec_x, sunvec_z) &
-       result(no_zero_found) bind(C)
+    result(no_zero_found) bind(C)
 
     implicit none
     type(N_Vector)      :: sunvec_x
     type(N_Vector)      :: sunvec_z
     type(FVec), pointer :: x, z
-    integer(c_long)     :: i
+    integer(c_int64_t)     :: i
 
     ! extract Fortran vector structures to work with
     x => FN_VGetFVec(sunvec_x)
@@ -580,12 +579,12 @@ contains
 
     ! perform operation and return
     no_zero_found = 1
-    do i = 1,x%len
-       if (x%data(i) == dcmplx(0.d0, 0.d0)) then
-          no_zero_found = 0
-       else
-          z%data(i) = 1.d0 / x%data(i)
-       end if
+    do i = 1, x%len
+      if (x%data(i) == dcmplx(0.d0, 0.d0)) then
+        no_zero_found = 0
+      else
+        z%data(i) = 1.d0/x%data(i)
+      end if
     end do
     return
 
