@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! ------------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -16,7 +16,13 @@
 
 module test_arkode_butcher_table
 
-  contains
+#if defined(SUNDIALS_INT32_T)
+  integer, parameter :: myindextype = selected_int_kind(8)
+#elif defined(SUNDIALS_INT64_T)
+  integer, parameter :: myindextype = selected_int_kind(16)
+#endif
+
+contains
 
   integer function smoke_tests() result(ret)
 
@@ -27,9 +33,9 @@ module test_arkode_butcher_table
     !======== Declarations ========
     implicit none
     type(c_ptr) :: ERK, DIRK
-    integer(C_INT)  :: ierr, q(1), p(1)
-    integer(C_LONG) :: liw(1), lrw(1)
-    real(C_DOUBLE)  :: b(2), c(2), d(2), A(4)
+    integer(C_INT) :: ierr, q(1), p(1)
+    integer(kind=myindextype) :: liw(1), lrw(1)
+    real(C_DOUBLE) :: b(2), c(2), d(2), A(4)
 
     !===== Setup ====
 
@@ -46,7 +52,7 @@ module test_arkode_butcher_table
     d(1) = 1.0d0
 
     !===== Test =====
-    ERK  = FARkodeButcherTable_LoadERK(ARKODE_HEUN_EULER_2_1_2)
+    ERK = FARkodeButcherTable_LoadERK(ARKODE_HEUN_EULER_2_1_2)
     DIRK = FARkodeButcherTable_LoadDIRK(ARKODE_SDIRK_2_1_2)
     ierr = FARkodeButcherTable_CheckOrder(ERK, q, p, C_NULL_PTR)
     ierr = FARkodeButcherTable_CheckARKOrder(ERK, DIRK, q, p, C_NULL_PTR)
@@ -54,10 +60,10 @@ module test_arkode_butcher_table
     call FARKodeButcherTable_Free(ERK)
     call FARKodeButcherTable_Free(DIRK)
 
-    ERK   = FARkodeButcherTable_Create(2, 2, 1, c, A, b, d)
-    DIRK  = FARkodeButcherTable_Alloc(2, 1)
+    ERK = FARkodeButcherTable_Create(2, 2, 1, c, A, b, d)
+    DIRK = FARkodeButcherTable_Alloc(2, 1)
     call FARKodeButcherTable_Free(DIRK)
-    DIRK  = FARkodeButcherTable_Copy(ERK)
+    DIRK = FARkodeButcherTable_Copy(ERK)
 
     !==== Cleanup =====
     call FARKodeButcherTable_Free(ERK)
@@ -69,7 +75,6 @@ module test_arkode_butcher_table
 
 end module
 
-
 program main
   !======== Inclusions ==========
   use, intrinsic :: iso_c_binding
