@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! ------------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -49,12 +49,13 @@ module ode_mod
 
   !======= Inclusions ===========
   use, intrinsic :: iso_c_binding
+  use fsundials_core_mod
 
   !======= Declarations =========
   implicit none
 
   ! number of equations
-  integer(c_long), parameter :: neq = 3
+  integer(c_int64_t), parameter :: neq = 3
 
   ! ODE parameters
   double precision, parameter :: lamda = -100.0d0
@@ -70,11 +71,10 @@ contains
   !   -1 = non-recoverable error
   ! ----------------------------------------------------------------
   integer(c_int) function RhsFn(tn, sunvec_y, sunvec_f, user_data) &
-       result(ierr) bind(C,name='RhsFn')
+    result(ierr) bind(C, name='RhsFn')
 
     !======= Inclusions ===========
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
 
     !======= Declarations =========
     implicit none
@@ -83,14 +83,14 @@ contains
     real(c_double), value :: tn        ! current time
     type(N_Vector)        :: sunvec_y  ! solution N_Vector
     type(N_Vector)        :: sunvec_f  ! rhs N_Vector
-    type(c_ptr),    value :: user_data ! user-defined data
+    type(c_ptr), value :: user_data ! user-defined data
 
     ! pointers to data in SUNDIALS vectors
     real(c_double), pointer :: yvec(:)
     real(c_double), pointer :: fvec(:)
 
     ! ODE system matrix
-    real(c_double) :: Amat(neq,neq)
+    real(c_double) :: Amat(neq, neq)
 
     !======= Internals ============
 
@@ -99,11 +99,11 @@ contains
     fvec => FN_VGetArrayPointer(sunvec_f)
 
     ! fill A matrix (column major ordering)
-    Amat = reshape([&
-         lamda/4.d0 - 23.d0/40.d0, lamda/4.d0 + 21.d0/40, lamda/2.d0 + 1.d0/20.d0,   &
-         lamda/4.d0 - 3.d0/40.d0,  lamda/4.d0 + 1.d0/40,  lamda/2.d0 + 1.d0/20.d0,   &
-         lamda/4.d0 + 13.d0/40.d0, lamda/4.d0 - 11.d0/40, lamda/2.d0 - 1.d0/20.d0 ], &
-         [3,3])
+    Amat = reshape([ &
+                   lamda/4.d0 - 23.d0/40.d0, lamda/4.d0 + 21.d0/40, lamda/2.d0 + 1.d0/20.d0, &
+                   lamda/4.d0 - 3.d0/40.d0, lamda/4.d0 + 1.d0/40, lamda/2.d0 + 1.d0/20.d0, &
+                   lamda/4.d0 + 13.d0/40.d0, lamda/4.d0 - 11.d0/40, lamda/2.d0 - 1.d0/20.d0], &
+                   [3, 3])
 
     ! fill RHS vector f(t,y) = A*y
     fvec = matmul(Amat, yvec(1:neq))
@@ -123,14 +123,13 @@ contains
   !   -1 = non-recoverable error
   ! ----------------------------------------------------------------
   integer(c_int) function JacFn(tn, sunvec_y, sunvec_f, sunmat_J, &
-       user_data, tmp1, tmp2, tmp3) &
-       result(ierr) bind(C,name='JacFn')
+                                user_data, tmp1, tmp2, tmp3) &
+    result(ierr) bind(C, name='JacFn')
 
     !======= Inclusions ===========
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
+
     use fsunmatrix_sparse_mod
-    use fsundials_matrix_mod
 
     !======= Declarations =========
     implicit none
@@ -144,9 +143,9 @@ contains
     type(N_Vector)        :: tmp1, tmp2, tmp3 ! workspace N_Vectors
 
     ! pointer to data in SUNDIALS matrix
-    integer(c_long), pointer :: Jidxptr(:)
-    integer(c_long), pointer :: Jidxval(:)
-    real(c_double),  pointer :: Jmat(:)
+    integer(c_int64_t), pointer :: Jidxptr(:)
+    integer(c_int64_t), pointer :: Jidxval(:)
+    real(c_double), pointer :: Jmat(:)
 
     !======= Internals ============
 
@@ -158,11 +157,10 @@ contains
     Jmat => FSUNSparseMatrix_Data(sunmat_J)
 
     ! fill J matrix (column major ordering)
-    Jmat =  &
-        [lamda/4.d0 - 23.d0/40.d0, lamda/4.d0 + 21.d0/40, lamda/2.d0 + 1.d0/20.d0,&
-         lamda/4.d0 - 3.d0/40.d0,  lamda/4.d0 + 1.d0/40,  lamda/2.d0 + 1.d0/20.d0,&
-         lamda/4.d0 + 13.d0/40.d0, lamda/4.d0 - 11.d0/40, lamda/2.d0 - 1.d0/20.d0]
-
+    Jmat = &
+      [lamda/4.d0 - 23.d0/40.d0, lamda/4.d0 + 21.d0/40, lamda/2.d0 + 1.d0/20.d0, &
+       lamda/4.d0 - 3.d0/40.d0, lamda/4.d0 + 1.d0/40, lamda/2.d0 + 1.d0/20.d0, &
+       lamda/4.d0 + 13.d0/40.d0, lamda/4.d0 - 11.d0/40, lamda/2.d0 - 1.d0/20.d0]
 
     Jidxptr = [0, 3, 6, 9]
     Jidxval = [0, 1, 2, 0, 1, 2, 0, 1, 2]
@@ -175,21 +173,15 @@ contains
 
 end module ode_mod
 
-
 program main
 
   !======= Inclusions ===========
   use, intrinsic :: iso_c_binding
-
-  use fsundials_context_mod      ! Fortran interface to SUNContext
+  use fsundials_core_mod          ! Access SUNDIALS core types, data structures, etc.
   use fcvode_mod                 ! Fortran interface to CVODE
   use fnvector_serial_mod        ! Fortran interface to serial N_Vector
   use fsunmatrix_sparse_mod      ! Fortran interface to sparse SUNMatrix
   use fsunlinsol_klu_mod         ! Fortran interface to KLU SUNLinearSolver
-  use fsundials_linearsolver_mod ! Fortran interface to generic SUNLinearSolver
-  use fsundials_matrix_mod       ! Fortran interface to generic SUNMatrix
-  use fsundials_nvector_mod      ! Fortran interface to generic N_Vector
-  use fsundials_linearsolver_mod ! Fortran interface to generic SUNLinearSolver
   use ode_mod                    ! ODE functions
 
   !======= Declarations =========
@@ -209,8 +201,8 @@ program main
 
   integer :: outstep           ! output loop counter
 
-  type(N_Vector),        pointer :: sunvec_y      ! sundials vector
-  type(SUNMatrix),       pointer :: sunmat_A      ! sundials matrix
+  type(N_Vector), pointer :: sunvec_y      ! sundials vector
+  type(SUNMatrix), pointer :: sunmat_A      ! sundials matrix
   type(SUNLinearSolver), pointer :: sunlinsol_LS  ! sundials linear solver
 
   type(c_ptr) :: cvode_mem     ! CVODE memory
@@ -222,56 +214,56 @@ program main
 
   ! initialize ODE
   tstart = 0.0d0
-  tend   = 0.05d0
-  tcur   = tstart
-  tout   = tstart
-  dtout  = 0.005d0
-  nout   = ceiling(tend/dtout)
+  tend = 0.05d0
+  tcur = tstart
+  tout = tstart
+  dtout = 0.005d0
+  nout = ceiling(tend/dtout)
 
   ! initialize solution vector
   yvec(1) = 1.0d0
   yvec(2) = 1.0d0
   yvec(3) = 1.0d0
 
-  ierr = FSUNContext_Create(c_null_ptr, sunctx)
+  ierr = FSUNContext_Create(SUN_COMM_NULL, sunctx)
   if (ierr /= 0) then
-     print *, 'ERROR: FSUNContext_Create returned non-zero'
-     stop 1
+    print *, 'ERROR: FSUNContext_Create returned non-zero'
+    stop 1
   end if
 
   ! create a serial vector
   sunvec_y => FN_VMake_Serial(neq, yvec, sunctx)
   if (.not. associated(sunvec_y)) then
-     print *, 'ERROR: sunvec = NULL'
-     stop 1
+    print *, 'ERROR: sunvec = NULL'
+    stop 1
   end if
 
   ! create a sparse matrix
   sunmat_A => FSUNSparseMatrix(neq, neq, neq*neq, CSC_MAT, sunctx)
   if (.not. associated(sunmat_A)) then
-     print *, 'ERROR: sunmat = NULL'
-     stop 1
+    print *, 'ERROR: sunmat = NULL'
+    stop 1
   end if
 
   ! create a klu linear solver
   sunlinsol_LS => FSUNLinSol_KLU(sunvec_y, sunmat_A, sunctx)
   if (.not. associated(sunlinsol_LS)) then
-     print *, 'ERROR: sunlinsol = NULL'
-     stop 1
+    print *, 'ERROR: sunlinsol = NULL'
+    stop 1
   end if
 
   ! create CVode memory
   cvode_mem = FCVodeCreate(CV_BDF, sunctx)
   if (.not. c_associated(cvode_mem)) then
-     print *, 'ERROR: cvode_mem = NULL'
-     stop 1
+    print *, 'ERROR: cvode_mem = NULL'
+    stop 1
   end if
 
   ! initialize CVode
   ierr = FCVodeInit(cvode_mem, c_funloc(RhsFn), tstart, sunvec_y)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeInit, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeInit, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! set relative and absolute tolerances
@@ -280,22 +272,22 @@ program main
 
   ierr = FCVodeSStolerances(cvode_mem, rtol, atol)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeSStolerances, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeSStolerances, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! attach linear solver
   ierr = FCVodeSetLinearSolver(cvode_mem, sunlinsol_LS, sunmat_A)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeSetLinearSolver, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeSetLinearSolver, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! set Jacobian routine
   ierr = FCVodeSetJacFn(cvode_mem, c_funloc(JacFn))
   if (ierr /= 0) then
-     print *, 'Error in FCVodeSetJacFn, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeSetJacFn, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! start time stepping
@@ -305,20 +297,20 @@ program main
   print *, '       t           y1           y2           y3       '
   print *, '------------------------------------------------------'
   print '(2x,4(es12.5,1x))', tcur, yvec(1), yvec(2), yvec(3)
-  do outstep = 1,nout
+  do outstep = 1, nout
 
-     ! call CVode
-     tout = min(tout + dtout, tend)
-     ierr = FCVode(cvode_mem, tout, sunvec_y, tcur, CV_NORMAL)
-     if (ierr /= 0) then
-        print *, 'Error in FCVODE, ierr = ', ierr, '; halting'
-        stop 1
-     endif
+    ! call CVode
+    tout = min(tout + dtout, tend)
+    ierr = FCVode(cvode_mem, tout, sunvec_y, tcur, CV_NORMAL)
+    if (ierr /= 0) then
+      print *, 'Error in FCVODE, ierr = ', ierr, '; halting'
+      stop 1
+    end if
 
-     ! output current solution
-     print '(2x,4(es12.5,1x))', tcur, yvec(1), yvec(2), yvec(3)
+    ! output current solution
+    print '(2x,4(es12.5,1x))', tcur, yvec(1), yvec(2), yvec(3)
 
-  enddo
+  end do
 
   ! diagnostics output
   call CVodeStats(cvode_mem)
@@ -332,7 +324,6 @@ program main
 
 end program main
 
-
 ! ----------------------------------------------------------------
 ! CVodeStats
 !
@@ -373,41 +364,41 @@ subroutine CVodeStats(cvode_mem)
 
   ! general solver statistics
   ierr = FCVodeGetIntegratorStats(cvode_mem, nsteps, nfevals, nlinsetups, &
-       netfails, qlast, qcur, hinused, hlast, hcur, tcur)
+                                  netfails, qlast, qcur, hinused, hlast, hcur, tcur)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeGetIntegratorStats, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeGetIntegratorStats, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! nonlinear solver statistics
   ierr = FCVodeGetNonlinSolvStats(cvode_mem, nniters, nncfails)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeGetNonlinSolvStats, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeGetNonlinSolvStats, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! number of Jacobian evaluations
   ierr = FCVodeGetNumJacEvals(cvode_mem, njevals)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeGetNumJacEvals, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeGetNumJacEvals, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   print *, ' '
   print *, ' General Solver Stats:'
-  print '(4x,A,i9)'    ,'Total internal steps taken =',nsteps
-  print '(4x,A,i9)'    ,'Total rhs function calls   =',nfevals
-  print '(4x,A,i9)'    ,'Num lin solver setup calls =',nlinsetups
-  print '(4x,A,i9)'    ,'Num error test failures    =',netfails
-  print '(4x,A,i9)'    ,'Last method order          =',qlast
-  print '(4x,A,i9)'    ,'Next method order          =',qcur
-  print '(4x,A,es12.5)','First internal step size   =',hinused
-  print '(4x,A,es12.5)','Last internal step size    =',hlast
-  print '(4x,A,es12.5)','Next internal step size    =',hcur
-  print '(4x,A,es12.5)','Current internal time      =',tcur
-  print '(4x,A,i9)'    ,'Num nonlinear solver iters =',nniters
-  print '(4x,A,i9)'    ,'Num nonlinear solver fails =',nncfails
-  print '(4x,A,i9)'    ,'Num Jacobian evaluations   =',njevals
+  print '(4x,A,i9)', 'Total internal steps taken =', nsteps
+  print '(4x,A,i9)', 'Total rhs function calls   =', nfevals
+  print '(4x,A,i9)', 'Num lin solver setup calls =', nlinsetups
+  print '(4x,A,i9)', 'Num error test failures    =', netfails
+  print '(4x,A,i9)', 'Last method order          =', qlast
+  print '(4x,A,i9)', 'Next method order          =', qcur
+  print '(4x,A,es12.5)', 'First internal step size   =', hinused
+  print '(4x,A,es12.5)', 'Last internal step size    =', hlast
+  print '(4x,A,es12.5)', 'Next internal step size    =', hcur
+  print '(4x,A,es12.5)', 'Current internal time      =', tcur
+  print '(4x,A,i9)', 'Num nonlinear solver iters =', nniters
+  print '(4x,A,i9)', 'Num nonlinear solver fails =', nncfails
+  print '(4x,A,i9)', 'Num Jacobian evaluations   =', njevals
   print *, ' '
 
   return
