@@ -2,7 +2,7 @@
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -32,12 +32,11 @@
  * Run statistics (optional outputs) are printed at the end.
  * -----------------------------------------------------------------*/
 
+#include <cvodes/cvodes.h>          /* prototypes for CVODE fcts., consts.  */
+#include <nvector/nvector_serial.h> /* access to serial N_Vector            */
 #include <stdio.h>
-
-#include <cvodes/cvodes.h>                   /* prototypes for CVODE fcts., consts.  */
-#include <nvector/nvector_serial.h>          /* access to serial N_Vector            */
-#include <sunmatrix/sunmatrix_dense.h>       /* access to dense SUNMatrix            */
 #include <sunlinsol/sunlinsol_lapackdense.h> /* access to dense SUNLinearSolver      */
+#include <sunmatrix/sunmatrix_dense.h> /* access to dense SUNMatrix            */
 
 /* User-defined vector and matrix accessor macros: Ith, IJth */
 
@@ -54,48 +53,49 @@
    SM_ELEMENT_D macro. SM_ELEMENT_D numbers rows and columns of
    a dense matrix starting from 0. */
 
-#define Ith(v,i)    NV_Ith_S(v,i-1)         /* i-th vector component i=1..NEQ */
-#define IJth(A,i,j) SM_ELEMENT_D(A,i-1,j-1) /* (i,j)-th matrix component i,j=1..NEQ */
+#define Ith(v, i) NV_Ith_S(v, i - 1) /* i-th vector component i=1..NEQ */
+#define IJth(A, i, j) \
+  SM_ELEMENT_D(A, i - 1, j - 1) /* (i,j)-th matrix component i,j=1..NEQ */
 
 /* Problem Constants */
 
-#define NEQ   3                /* number of equations  */
-#define Y1    RCONST(1.0)      /* initial y components */
-#define Y2    RCONST(0.0)
-#define Y3    RCONST(0.0)
-#define RTOL  RCONST(1.0e-4)   /* scalar relative tolerance            */
-#define ATOL1 RCONST(1.0e-8)   /* vector absolute tolerance components */
-#define ATOL2 RCONST(1.0e-14)
-#define ATOL3 RCONST(1.0e-6)
-#define T0    RCONST(0.0)      /* initial time           */
-#define T1    RCONST(0.4)      /* first output time      */
-#define TMULT RCONST(10.0)     /* output time factor     */
+#define NEQ   3               /* number of equations  */
+#define Y1    SUN_RCONST(1.0) /* initial y components */
+#define Y2    SUN_RCONST(0.0)
+#define Y3    SUN_RCONST(0.0)
+#define RTOL  SUN_RCONST(1.0e-4) /* scalar relative tolerance            */
+#define ATOL1 SUN_RCONST(1.0e-8) /* vector absolute tolerance components */
+#define ATOL2 SUN_RCONST(1.0e-14)
+#define ATOL3 SUN_RCONST(1.0e-6)
+#define T0    SUN_RCONST(0.0)  /* initial time           */
+#define T1    SUN_RCONST(0.4)  /* first output time      */
+#define TMULT SUN_RCONST(10.0) /* output time factor     */
 #define NOUT  12               /* number of output times */
 
-#define ZERO  RCONST(0.0)
+#define ZERO SUN_RCONST(0.0)
 
 /* Functions Called by the Solver */
 
-static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data);
+static int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data);
 
-static int g(realtype t, N_Vector y, realtype *gout, void *user_data);
+static int g(sunrealtype t, N_Vector y, sunrealtype* gout, void* user_data);
 
-static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
-               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
+static int Jac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void* user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
 
 /* Private functions to output results */
 
-static void PrintOutput(realtype t, realtype y1, realtype y2, realtype y3);
+static void PrintOutput(sunrealtype t, sunrealtype y1, sunrealtype y2,
+                        sunrealtype y3);
 static void PrintRootInfo(int root_f1, int root_f2);
 
 /* Private function to print final statistics */
 
-static void PrintFinalStats(void *cvode_mem);
+static void PrintFinalStats(void* cvode_mem);
 
 /* Private function to check function return values */
 
-static int check_retval(void *returnvalue, const char *funcname, int opt);
-
+static int check_retval(void* returnvalue, const char* funcname, int opt);
 
 /*
  *-------------------------------
@@ -103,121 +103,124 @@ static int check_retval(void *returnvalue, const char *funcname, int opt);
  *-------------------------------
  */
 
-int main()
+int main(void)
 {
   SUNContext sunctx;
-  realtype t, tout;
+  sunrealtype t, tout;
   N_Vector y;
   N_Vector abstol;
   SUNMatrix A;
   SUNLinearSolver LS;
-  void *cvode_mem;
+  void* cvode_mem;
   int retval, iout;
   int retvalr;
   int rootsfound[2];
 
-  y = NULL;
-  abstol = NULL;
-  A = NULL;
-  LS = NULL;
+  y         = NULL;
+  abstol    = NULL;
+  A         = NULL;
+  LS        = NULL;
   cvode_mem = NULL;
 
   /* Create the SUNDIALS context */
-  retval = SUNContext_Create(NULL, &sunctx);
-  if (check_retval(&retval, "SUNContext_Create", 1)) return(1);
+  retval = SUNContext_Create(SUN_COMM_NULL, &sunctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) { return (1); }
 
   /* Initial conditions */
   y = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)y, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)y, "N_VNew_Serial", 0)) { return (1); }
 
   /* Initialize y */
-  Ith(y,1) = Y1;
-  Ith(y,2) = Y2;
-  Ith(y,3) = Y3;
+  Ith(y, 1) = Y1;
+  Ith(y, 2) = Y2;
+  Ith(y, 3) = Y3;
 
   /* Set the vector absolute tolerance */
   abstol = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)abstol, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)abstol, "N_VNew_Serial", 0)) { return (1); }
 
-  Ith(abstol,1) = ATOL1;
-  Ith(abstol,2) = ATOL2;
-  Ith(abstol,3) = ATOL3;
+  Ith(abstol, 1) = ATOL1;
+  Ith(abstol, 2) = ATOL2;
+  Ith(abstol, 3) = ATOL3;
 
   /* Call CVodeCreate to create the solver memory and specify the
    * Backward Differentiation Formula */
   cvode_mem = CVodeCreate(CV_BDF, sunctx);
-  if (check_retval((void *)cvode_mem, "CVodeCreate", 0)) return(1);
+  if (check_retval((void*)cvode_mem, "CVodeCreate", 0)) { return (1); }
 
   /* Call CVodeInit to initialize the integrator memory and specify the
    * user's right hand side function in y'=f(t,y), the initial time T0, and
    * the initial dependent variable vector y. */
   retval = CVodeInit(cvode_mem, f, T0, y);
-  if (check_retval(&retval, "CVodeInit", 1)) return(1);
+  if (check_retval(&retval, "CVodeInit", 1)) { return (1); }
 
   /* Call CVodeSVtolerances to specify the scalar relative tolerance
    * and vector absolute tolerances */
   retval = CVodeSVtolerances(cvode_mem, RTOL, abstol);
-  if (check_retval(&retval, "CVodeSVtolerances", 1)) return(1);
+  if (check_retval(&retval, "CVodeSVtolerances", 1)) { return (1); }
 
   /* Call CVodeRootInit to specify the root function g with 2 components */
   retval = CVodeRootInit(cvode_mem, 2, g);
-  if (check_retval(&retval, "CVodeRootInit", 1)) return(1);
+  if (check_retval(&retval, "CVodeRootInit", 1)) { return (1); }
 
   /* Create dense SUNMatrix for use in linear solves */
   A = SUNDenseMatrix(NEQ, NEQ, sunctx);
-  if (check_retval((void *)A, "SUNDenseMatrix", 0)) return(1);
+  if (check_retval((void*)A, "SUNDenseMatrix", 0)) { return (1); }
 
   /* Create SUNLinSol_LapackDense solver object for use by CVode */
   LS = SUNLinSol_LapackDense(y, A, sunctx);
-  if (check_retval((void *)LS, "SUNLinSol_LapackDense", 0)) return(1);
+  if (check_retval((void*)LS, "SUNLinSol_LapackDense", 0)) { return (1); }
 
   /* Attach the matrix and linear solver */
   retval = CVodeSetLinearSolver(cvode_mem, LS, A);
-  if (check_retval(&retval, "CVodeSetLinearSolver", 1)) return(1);
+  if (check_retval(&retval, "CVodeSetLinearSolver", 1)) { return (1); }
 
   /* Set the user-supplied Jacobian routine Jac */
   retval = CVodeSetJacFn(cvode_mem, Jac);
-  if (check_retval(&retval, "CVodeSetJacFn", 1)) return(1);
+  if (check_retval(&retval, "CVodeSetJacFn", 1)) { return (1); }
 
   /* In loop, call CVode, print results, and test for error.
      Break out of loop when NOUT preset output times have been reached.  */
   printf(" \n3-species kinetics problem\n\n");
 
-  iout = 0;  tout = T1;
-  while(1) {
+  iout = 0;
+  tout = T1;
+  while (1)
+  {
     retval = CVode(cvode_mem, tout, y, &t, CV_NORMAL);
-    PrintOutput(t, Ith(y,1), Ith(y,2), Ith(y,3));
+    PrintOutput(t, Ith(y, 1), Ith(y, 2), Ith(y, 3));
 
-    if (retval == CV_ROOT_RETURN) {
+    if (retval == CV_ROOT_RETURN)
+    {
       retvalr = CVodeGetRootInfo(cvode_mem, rootsfound);
-      if (check_retval(&retvalr, "CVodeGetRootInfo", 1)) return(1);
-      PrintRootInfo(rootsfound[0],rootsfound[1]);
+      if (check_retval(&retvalr, "CVodeGetRootInfo", 1)) { return (1); }
+      PrintRootInfo(rootsfound[0], rootsfound[1]);
     }
 
-    if (check_retval(&retval, "CVode", 1)) break;
-    if (retval == CV_SUCCESS) {
+    if (check_retval(&retval, "CVode", 1)) { break; }
+    if (retval == CV_SUCCESS)
+    {
       iout++;
       tout *= TMULT;
     }
 
-    if (iout == NOUT) break;
+    if (iout == NOUT) { break; }
   }
 
   /* Print some final statistics */
   PrintFinalStats(cvode_mem);
 
   /* Free memory */
-  N_VDestroy(y);                            /* Free y vector */
-  N_VDestroy(abstol);                       /* Free abstol vector */
-  CVodeFree(&cvode_mem);                    /* Free CVODES memory */
-  SUNLinSolFree(LS);                        /* Free the linear solver memory */
-  SUNMatDestroy(A);                         /* Free the matrix memory */
-  SUNContext_Free(&sunctx);                 /* Free the SUNDIALS context */
+  N_VDestroy(y);            /* Free y vector */
+  N_VDestroy(abstol);       /* Free abstol vector */
+  CVodeFree(&cvode_mem);    /* Free CVODES memory */
+  SUNLinSolFree(LS);        /* Free the linear solver memory */
+  SUNMatDestroy(A);         /* Free the matrix memory */
+  SUNContext_Free(&sunctx); /* Free the SUNDIALS context */
 
-  return(0);
+  return (0);
 }
 
-
 /*
  *-------------------------------
  * Functions called by the solver
@@ -228,58 +231,62 @@ int main()
  * f routine. Compute function f(t,y).
  */
 
-static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data)
+static int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data)
 {
-  realtype y1, y2, y3, yd1, yd3;
+  sunrealtype y1, y2, y3, yd1, yd3;
 
-  y1 = Ith(y,1); y2 = Ith(y,2); y3 = Ith(y,3);
+  y1 = Ith(y, 1);
+  y2 = Ith(y, 2);
+  y3 = Ith(y, 3);
 
-  yd1 = Ith(ydot,1) = RCONST(-0.04)*y1 + RCONST(1.0e4)*y2*y3;
-  yd3 = Ith(ydot,3) = RCONST(3.0e7)*y2*y2;
-        Ith(ydot,2) = -yd1 - yd3;
+  yd1 = Ith(ydot, 1) = SUN_RCONST(-0.04) * y1 + SUN_RCONST(1.0e4) * y2 * y3;
+  yd3 = Ith(ydot, 3) = SUN_RCONST(3.0e7) * y2 * y2;
+  Ith(ydot, 2)       = -yd1 - yd3;
 
-  return(0);
+  return (0);
 }
 
 /*
  * g routine. Compute functions g_i(t,y) for i = 0,1.
  */
 
-static int g(realtype t, N_Vector y, realtype *gout, void *user_data)
+static int g(sunrealtype t, N_Vector y, sunrealtype* gout, void* user_data)
 {
-  realtype y1, y3;
+  sunrealtype y1, y3;
 
-  y1 = Ith(y,1); y3 = Ith(y,3);
-  gout[0] = y1 - RCONST(0.0001);
-  gout[1] = y3 - RCONST(0.01);
+  y1      = Ith(y, 1);
+  y3      = Ith(y, 3);
+  gout[0] = y1 - SUN_RCONST(0.0001);
+  gout[1] = y3 - SUN_RCONST(0.01);
 
-  return(0);
+  return (0);
 }
 
 /*
  * Jacobian routine. Compute J(t,y) = df/dy. *
  */
 
-static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
-               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
+static int Jac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void* user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
 {
-  realtype y2, y3;
+  sunrealtype y2, y3;
 
-  y2 = Ith(y,2); y3 = Ith(y,3);
+  y2 = Ith(y, 2);
+  y3 = Ith(y, 3);
 
-  IJth(J,1,1) = RCONST(-0.04);
-  IJth(J,1,2) = RCONST(1.0e4)*y3;
-  IJth(J,1,3) = RCONST(1.0e4)*y2;
+  IJth(J, 1, 1) = SUN_RCONST(-0.04);
+  IJth(J, 1, 2) = SUN_RCONST(1.0e4) * y3;
+  IJth(J, 1, 3) = SUN_RCONST(1.0e4) * y2;
 
-  IJth(J,2,1) = RCONST(0.04);
-  IJth(J,2,2) = RCONST(-1.0e4)*y3-RCONST(6.0e7)*y2;
-  IJth(J,2,3) = RCONST(-1.0e4)*y2;
+  IJth(J, 2, 1) = SUN_RCONST(0.04);
+  IJth(J, 2, 2) = SUN_RCONST(-1.0e4) * y3 - SUN_RCONST(6.0e7) * y2;
+  IJth(J, 2, 3) = SUN_RCONST(-1.0e4) * y2;
 
-  IJth(J,3,1) = ZERO;
-  IJth(J,3,2) = RCONST(6.0e7)*y2;
-  IJth(J,3,3) = ZERO;
+  IJth(J, 3, 1) = ZERO;
+  IJth(J, 3, 2) = SUN_RCONST(6.0e7) * y2;
+  IJth(J, 3, 3) = ZERO;
 
-  return(0);
+  return (0);
 }
 
 /*
@@ -288,7 +295,8 @@ static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
  *-------------------------------
  */
 
-static void PrintOutput(realtype t, realtype y1, realtype y2, realtype y3)
+static void PrintOutput(sunrealtype t, sunrealtype y1, sunrealtype y2,
+                        sunrealtype y3)
 {
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("At t = %0.4Le      y =%14.6Le  %14.6Le  %14.6Le\n", t, y1, y2, y3);
@@ -312,7 +320,7 @@ static void PrintRootInfo(int root_f1, int root_f2)
  * Get and print some final statistics
  */
 
-static void PrintFinalStats(void *cvode_mem)
+static void PrintFinalStats(void* cvode_mem)
 {
   long int nst, nfe, nsetups, nje, nfeLS, nni, nnf, ncfn, netf, nge;
   int retval;
@@ -357,29 +365,37 @@ static void PrintFinalStats(void *cvode_mem)
  *            NULL pointer
  */
 
-static int check_retval(void *returnvalue, const char *funcname, int opt)
+static int check_retval(void* returnvalue, const char* funcname, int opt)
 {
-  int *retval;
+  int* retval;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && returnvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL)
+  {
     fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1); }
+    return (1);
+  }
 
   /* Check if retval < 0 */
-  else if (opt == 1) {
-    retval = (int *) returnvalue;
-    if (*retval < 0) {
+  else if (opt == 1)
+  {
+    retval = (int*)returnvalue;
+    if (*retval < 0)
+    {
       fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
               funcname, *retval);
-      return(1); }}
+      return (1);
+    }
+  }
 
   /* Check if function returned NULL pointer - no memory allocated */
-  else if (opt == 2 && returnvalue == NULL) {
+  else if (opt == 2 && returnvalue == NULL)
+  {
     fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1); }
+    return (1);
+  }
 
-  return(0);
+  return (0);
 }
