@@ -3,7 +3,7 @@
  * Programmer(s): Daniel R. Reynolds and Ting Yan @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -105,15 +105,14 @@
  * -----------------------------------------------------------------
  */
 
+#include <idas/idas.h>
+#include <math.h>
+#include <nvector/nvector_openmp.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <math.h>
-
-#include <idas/idas.h>
-#include <sunlinsol/sunlinsol_spgmr.h>
-#include <nvector/nvector_openmp.h>
 #include <sundials/sundials_dense.h>
 #include <sundials/sundials_types.h>
+#include <sunlinsol/sunlinsol_spgmr.h>
 
 #ifdef _OPENMP
 #include <omp.h>
@@ -127,33 +126,33 @@
 
 /* Problem Constants. */
 
-#define NPREY       1              /* No. of prey (= no. of predators). */
-#define NUM_SPECIES 2*NPREY
+#define NPREY       1 /* No. of prey (= no. of predators). */
+#define NUM_SPECIES 2 * NPREY
 
-#define PI          RCONST(3.1415926535898)
-#define FOURPI      (RCONST(4.0)*PI)
+#define PI     SUN_RCONST(3.1415926535898)
+#define FOURPI (SUN_RCONST(4.0) * PI)
 
-#define MX          20             /* MX = number of x mesh points      */
-#define MY          20             /* MY = number of y mesh points      */
-#define NSMX        (NUM_SPECIES * MX)
-#define NEQ         (NUM_SPECIES*MX*MY)
-#define AA          RCONST(1.0)    /* Coefficient in above eqns. for a  */
-#define EE          RCONST(10000.) /* Coefficient in above eqns. for a  */
-#define GG          RCONST(0.5e-6) /* Coefficient in above eqns. for a  */
-#define BB          RCONST(1.0)    /* Coefficient in above eqns. for b  */
-#define DPREY       RCONST(1.0)    /* Coefficient in above eqns. for d  */
-#define DPRED       RCONST(0.05)   /* Coefficient in above eqns. for d  */
-#define ALPHA       RCONST(50.)    /* Coefficient alpha in above eqns.  */
-#define BETA        RCONST(1000.)  /* Coefficient beta in above eqns.   */
-#define AX          RCONST(1.0)    /* Total range of x variable         */
-#define AY          RCONST(1.0)    /* Total range of y variable         */
-#define RTOL        RCONST(1.e-5)  /* Relative tolerance                */
-#define ATOL        RCONST(1.e-5)  /* Absolute tolerance                */
-#define NOUT        6              /* Number of output times            */
-#define TMULT       RCONST(10.0)   /* Multiplier for tout values        */
-#define TADD        RCONST(0.3)    /* Increment for tout values         */
-#define ZERO        RCONST(0.)
-#define ONE         RCONST(1.0)
+#define MX    20 /* MX = number of x mesh points      */
+#define MY    20 /* MY = number of y mesh points      */
+#define NSMX  (NUM_SPECIES * MX)
+#define NEQ   (NUM_SPECIES * MX * MY)
+#define AA    SUN_RCONST(1.0)    /* Coefficient in above eqns. for a  */
+#define EE    SUN_RCONST(10000.) /* Coefficient in above eqns. for a  */
+#define GG    SUN_RCONST(0.5e-6) /* Coefficient in above eqns. for a  */
+#define BB    SUN_RCONST(1.0)    /* Coefficient in above eqns. for b  */
+#define DPREY SUN_RCONST(1.0)    /* Coefficient in above eqns. for d  */
+#define DPRED SUN_RCONST(0.05)   /* Coefficient in above eqns. for d  */
+#define ALPHA SUN_RCONST(50.)    /* Coefficient alpha in above eqns.  */
+#define BETA  SUN_RCONST(1000.)  /* Coefficient beta in above eqns.   */
+#define AX    SUN_RCONST(1.0)    /* Total range of x variable         */
+#define AY    SUN_RCONST(1.0)    /* Total range of y variable         */
+#define RTOL  SUN_RCONST(1.e-5)  /* Relative tolerance                */
+#define ATOL  SUN_RCONST(1.e-5)  /* Absolute tolerance                */
+#define NOUT  6                  /* Number of output times            */
+#define TMULT SUN_RCONST(10.0)   /* Multiplier for tout values        */
+#define TADD  SUN_RCONST(0.3)    /* Increment for tout values         */
+#define ZERO  SUN_RCONST(0.)
+#define ONE   SUN_RCONST(1.0)
 
 /*
  * User-defined vector and accessor macro: IJ_Vptr.
@@ -163,47 +162,49 @@
  * species index is = 0, x-index ix = i, and y-index jy = j.
  */
 
-#define IJ_Vptr(vv,i,j) (&NV_Ith_OMP(vv, (i)*NUM_SPECIES + (j)*NSMX))
+#define IJ_Vptr(vv, i, j) (&NV_Ith_OMP(vv, (i) * NUM_SPECIES + (j) * NSMX))
 
 /* Type: UserData.  Contains problem constants, etc. */
 
-typedef struct {
+typedef struct
+{
   sunindextype Neq, ns, np, mx, my;
-  realtype dx, dy, **acoef;
-  realtype cox[NUM_SPECIES], coy[NUM_SPECIES], bcoef[NUM_SPECIES];
-  realtype **PP[MX][MY];
-  sunindextype *pivot[MX][MY];
+  sunrealtype dx, dy, **acoef;
+  sunrealtype cox[NUM_SPECIES], coy[NUM_SPECIES], bcoef[NUM_SPECIES];
+  sunrealtype** PP[MX][MY];
+  sunindextype* pivot[MX][MY];
   N_Vector rates;
   N_Vector ewt;
-  void *ida_mem;
+  void* ida_mem;
   int nthreads;
-} *UserData;
+}* UserData;
 
 /* Prototypes for functions called by the IDA Solver. */
 
-static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval,
-                  void *user_data);
+static int resweb(sunrealtype time, N_Vector cc, N_Vector cp, N_Vector resval,
+                  void* user_data);
 
-static int Precond(realtype tt, N_Vector cc, N_Vector cp,
-                   N_Vector rr, realtype cj, void *user_data);
+static int Precond(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector rr,
+                   sunrealtype cj, void* user_data);
 
-static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
-                  N_Vector rr, N_Vector rvec, N_Vector zvec,
-                  realtype cj, realtype delta, void *user_data);
+static int PSolve(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector rr,
+                  N_Vector rvec, N_Vector zvec, sunrealtype cj,
+                  sunrealtype delta, void* user_data);
 
 /* Prototypes for private Helper Functions. */
 
 static void InitUserData(UserData webdata);
 static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
                                UserData webdata);
-static void PrintHeader(int maxl, realtype rtol, realtype atol);
-static void PrintOutput(void *ida_mem, N_Vector c, realtype t);
-static void PrintFinalStats(void *ida_mem);
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate, UserData webdata);
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
-                     UserData webdata);
-static realtype dotprod(sunindextype size, realtype *x1, realtype *x2);
-static int check_retval(void *returnvalue, char *funcname, int opt);
+static void PrintHeader(int maxl, sunrealtype rtol, sunrealtype atol);
+static void PrintOutput(void* ida_mem, N_Vector c, sunrealtype t);
+static void PrintFinalStats(void* ida_mem);
+static void Fweb(sunrealtype tcalc, N_Vector cc, N_Vector crate,
+                 UserData webdata);
+static void WebRates(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                     sunrealtype* ratesxy, UserData webdata);
+static sunrealtype dotprod(sunindextype size, sunrealtype* x1, sunrealtype* x2);
+static int check_retval(void* returnvalue, char* funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -211,44 +212,45 @@ static int check_retval(void *returnvalue, char *funcname, int opt);
  *--------------------------------------------------------------------
  */
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
-  void *ida_mem;
+  void* ida_mem;
   SUNLinearSolver LS;
   UserData webdata;
   N_Vector cc, cp, id;
   int iout, jx, jy, retval;
   int maxl;
-  realtype rtol, atol, t0, tout, tret;
+  sunrealtype rtol, atol, t0, tout, tret;
   int num_threads;
   SUNContext ctx;
 
   ida_mem = NULL;
-  LS = NULL;
+  LS      = NULL;
   webdata = NULL;
   cc = cp = id = NULL;
 
   /* Set the number of threads to use */
-  num_threads = 1;   /* default value */
+  num_threads = 1; /* default value */
 #ifdef _OPENMP
-  num_threads = omp_get_max_threads();    /* overwrite with OMP_NUM_THREADS */
+  num_threads = omp_get_max_threads(); /* overwrite with OMP_NUM_THREADS */
 #endif
-  if (argc > 1)
-    num_threads = (int) strtol(argv[1], NULL, 0);
+  if (argc > 1) { num_threads = (int)strtol(argv[1], NULL, 0); }
 
   /* Create the SUNDIALS context object for this simulation */
 
-  retval = SUNContext_Create(NULL, &ctx);
-  if (check_retval(&retval, "SUNContext_Create", 1)) return 1;
+  retval = SUNContext_Create(SUN_COMM_NULL, &ctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) { return 1; }
 
   /* Allocate and initialize user data block webdata. */
 
-  webdata = (UserData) malloc(sizeof *webdata);
+  webdata        = (UserData)malloc(sizeof *webdata);
   webdata->rates = N_VNew_OpenMP(NEQ, num_threads, ctx);
   webdata->acoef = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
-  webdata->ewt = N_VClone(webdata->rates);
-  for (jx = 0; jx < MX; jx++) {
-    for (jy = 0; jy < MY; jy++) {
+  webdata->ewt   = N_VClone(webdata->rates);
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
       (webdata->pivot)[jx][jy] = SUNDlsMat_newIndexArray(NUM_SPECIES);
       (webdata->PP)[jx][jy] = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
     }
@@ -260,59 +262,60 @@ int main(int argc, char *argv[])
   /* Allocate N-vectors and initialize cc, cp, and id. */
 
   cc = N_VNew_OpenMP(NEQ, num_threads, ctx);
-  if(check_retval((void *)cc, "N_VNew_OpenMP", 0)) return(1);
+  if (check_retval((void*)cc, "N_VNew_OpenMP", 0)) { return (1); }
 
   cp = N_VClone(cc);
-  if(check_retval((void *)cp, "N_VNew_OpenMP", 0)) return(1);
+  if (check_retval((void*)cp, "N_VNew_OpenMP", 0)) { return (1); }
 
   id = N_VClone(cc);
-  if(check_retval((void *)id, "N_VNew_OpenMP", 0)) return(1);
+  if (check_retval((void*)id, "N_VNew_OpenMP", 0)) { return (1); }
 
   SetInitialProfiles(cc, cp, id, webdata);
 
   /* Set remaining inputs to IDAMalloc. */
 
-  t0 = ZERO;
+  t0   = ZERO;
   rtol = RTOL;
   atol = ATOL;
 
   /* Call IDACreate and IDAMalloc to initialize IDA. */
 
   ida_mem = IDACreate(ctx);
-  if(check_retval((void *)ida_mem, "IDACreate", 0)) return(1);
+  if (check_retval((void*)ida_mem, "IDACreate", 0)) { return (1); }
 
   retval = IDASetUserData(ida_mem, webdata);
-  if(check_retval(&retval, "IDASetUserData", 1)) return(1);
+  if (check_retval(&retval, "IDASetUserData", 1)) { return (1); }
 
   retval = IDASetId(ida_mem, id);
-  if(check_retval(&retval, "IDASetId", 1)) return(1);
+  if (check_retval(&retval, "IDASetId", 1)) { return (1); }
 
   retval = IDAInit(ida_mem, resweb, t0, cc, cp);
-  if(check_retval(&retval, "IDAInit", 1)) return(1);
+  if (check_retval(&retval, "IDAInit", 1)) { return (1); }
 
   retval = IDASStolerances(ida_mem, rtol, atol);
-  if(check_retval(&retval, "IDASStolerances", 1)) return(1);
+  if (check_retval(&retval, "IDASStolerances", 1)) { return (1); }
 
   webdata->ida_mem = ida_mem;
 
   /* Create SUNLinSol_SPGMR linear solver, attach to IDA, and set
      preconditioning routines. */
 
-  maxl = 16;                                      /* max dimension of the Krylov subspace */
-  LS = SUNLinSol_SPGMR(cc, SUN_PREC_LEFT, maxl, ctx);      /* IDA only allows left preconditioning */
-  if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0)) return(1);
+  maxl = 16; /* max dimension of the Krylov subspace */
+  LS   = SUNLinSol_SPGMR(cc, SUN_PREC_LEFT, maxl,
+                         ctx); /* IDA only allows left preconditioning */
+  if (check_retval((void*)LS, "SUNLinSol_SPGMR", 0)) { return (1); }
 
   retval = IDASetLinearSolver(ida_mem, LS, NULL);
-  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
+  if (check_retval(&retval, "IDASetLinearSolver", 1)) { return (1); }
 
   retval = IDASetPreconditioner(ida_mem, Precond, PSolve);
-  if(check_retval(&retval, "IDASetPreconditioner", 1)) return(1);
+  if (check_retval(&retval, "IDASetPreconditioner", 1)) { return (1); }
 
   /* Call IDACalcIC (with default options) to correct the initial values. */
 
-  tout = RCONST(0.001);
+  tout   = SUN_RCONST(0.001);
   retval = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
-  if(check_retval(&retval, "IDACalcIC", 1)) return(1);
+  if (check_retval(&retval, "IDACalcIC", 1)) { return (1); }
 
   /* Print heading, basic parameters, and initial values. */
 
@@ -321,15 +324,15 @@ int main(int argc, char *argv[])
 
   /* Loop over iout, call IDASolve (normal mode), print selected output. */
 
-  for (iout = 1; iout <= NOUT; iout++) {
-
+  for (iout = 1; iout <= NOUT; iout++)
+  {
     retval = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
-    if(check_retval(&retval, "IDASolve", 1)) return(retval);
+    if (check_retval(&retval, "IDASolve", 1)) { return (retval); }
 
     PrintOutput(ida_mem, cc, tret);
 
-    if (iout < 3) tout *= TMULT; else tout += TADD;
-
+    if (iout < 3) { tout *= TMULT; }
+    else { tout += TADD; }
   }
 
   /* Print final statistics and free memory. */
@@ -346,12 +349,13 @@ int main(int argc, char *argv[])
   N_VDestroy(cp);
   N_VDestroy(id);
 
-
   SUNDlsMat_destroyMat(webdata->acoef);
   N_VDestroy(webdata->rates);
   N_VDestroy(webdata->ewt);
-  for (jx = 0; jx < MX; jx++) {
-    for (jy = 0; jy < MY; jy ++) {
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
       SUNDlsMat_destroyArray((webdata->pivot)[jx][jy]);
       SUNDlsMat_destroyMat((webdata->PP)[jx][jy]);
     }
@@ -360,15 +364,15 @@ int main(int argc, char *argv[])
 
   SUNContext_Free(&ctx);
 
-  return(0);
+  return (0);
 }
 
 /* Define lines for readability in later routines */
 
-#define acoef  (webdata->acoef)
-#define bcoef  (webdata->bcoef)
-#define cox    (webdata->cox)
-#define coy    (webdata->coy)
+#define acoef (webdata->acoef)
+#define bcoef (webdata->bcoef)
+#define cox   (webdata->cox)
+#define coy   (webdata->coy)
 
 /*
  *--------------------------------------------------------------------
@@ -383,11 +387,11 @@ int main(int argc, char *argv[])
  * using cp in the case of prey species.
  */
 
-static int resweb(realtype tt, N_Vector cc, N_Vector cp,
-                  N_Vector res,  void *user_data)
+static int resweb(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector res,
+                  void* user_data)
 {
   sunindextype jx, jy, is, yloc, loc, np;
-  realtype *resv, *cpv;
+  sunrealtype *resv, *cpv;
   UserData webdata;
 
   jx = jy = is = 0;
@@ -403,124 +407,130 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
 
   /* Loop over all grid points, setting residual values appropriately
      for differential or algebraic components.                        */
-#pragma omp parallel for default(shared) private(jy, jx, is, yloc, loc) schedule(static) num_threads(webdata->nthreads)
-  for (jy = 0; jy < MY; jy++) {
+#pragma omp parallel for default(shared) private(jy, jx, is, yloc, loc) \
+  schedule(static) num_threads(webdata->nthreads)
+  for (jy = 0; jy < MY; jy++)
+  {
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
+    for (jx = 0; jx < MX; jx++)
+    {
       loc = yloc + NUM_SPECIES * jx;
-      for (is = 0; is < NUM_SPECIES; is++) {
-        if (is < np)
-          resv[loc+is] = cpv[loc+is] - resv[loc+is];
-        else
-          resv[loc+is] = -resv[loc+is];
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
+        if (is < np) { resv[loc + is] = cpv[loc + is] - resv[loc + is]; }
+        else { resv[loc + is] = -resv[loc + is]; }
       }
     }
   }
 
-  return(0);
-
+  return (0);
 }
 
-
-static int Precond(realtype tt, N_Vector cc, N_Vector cp,
-                   N_Vector rr, realtype cj, void *user_data)
+static int Precond(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector rr,
+                   sunrealtype cj, void* user_data)
 {
   int retval;
   sunindextype ret;
-  realtype uround, xx, yy, del_x, del_y;
-  realtype **Pxy, *ratesxy, *Pxycol, *cxy, *cpxy, *ewtxy, cctmp;
-  realtype inc, fac, sqru, perturb_rates[NUM_SPECIES];
+  sunrealtype uround, xx, yy, del_x, del_y;
+  sunrealtype **Pxy, *ratesxy, *Pxycol, *cxy, *cpxy, *ewtxy, cctmp;
+  sunrealtype inc, fac, sqru, perturb_rates[NUM_SPECIES];
   int is, js, jx, jy;
-  void *ida_mem;
+  void* ida_mem;
   N_Vector ewt;
-  realtype hh;
+  sunrealtype hh;
   UserData webdata;
 
-  webdata = (UserData) user_data;
-  del_x = webdata->dx;
-  del_y = webdata->dy;
+  webdata = (UserData)user_data;
+  del_x   = webdata->dx;
+  del_y   = webdata->dy;
 
-  uround = UNIT_ROUNDOFF;
-  sqru = sqrt(uround);
+  uround = SUN_UNIT_ROUNDOFF;
+  sqru   = sqrt(uround);
 
   ida_mem = webdata->ida_mem;
-  ewt = webdata->ewt;
-  retval = IDAGetErrWeights(ida_mem, ewt);
-  if(check_retval(&retval, "IDAGetErrWeights", 1)) return(1);
+  ewt     = webdata->ewt;
+  retval  = IDAGetErrWeights(ida_mem, ewt);
+  if (check_retval(&retval, "IDAGetErrWeights", 1)) { return (1); }
   retval = IDAGetCurrentStep(ida_mem, &hh);
-  if(check_retval(&retval, "IDAGetCurrentStep", 1)) return(1);
+  if (check_retval(&retval, "IDAGetCurrentStep", 1)) { return (1); }
 
-  for (jy = 0; jy < MY; jy++) {
+  for (jy = 0; jy < MY; jy++)
+  {
     yy = jy * del_y;
 
-    for (jx = 0; jx < MX; jx++) {
-      xx = jx * del_x;
-      Pxy = (webdata->PP)[jx][jy];
-      cxy = IJ_Vptr(cc, jx, jy);
-      cpxy = IJ_Vptr(cp, jx, jy);
-      ewtxy = IJ_Vptr(ewt, jx, jy);
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx      = jx * del_x;
+      Pxy     = (webdata->PP)[jx][jy];
+      cxy     = IJ_Vptr(cc, jx, jy);
+      cpxy    = IJ_Vptr(cp, jx, jy);
+      ewtxy   = IJ_Vptr(ewt, jx, jy);
       ratesxy = IJ_Vptr((webdata->rates), jx, jy);
 
-      for (js = 0; js < NUM_SPECIES; js++) {
-        inc = sqru*(MAX(fabs(cxy[js]), MAX(hh*fabs(cpxy[js]), ONE/ewtxy[js])));
+      for (js = 0; js < NUM_SPECIES; js++)
+      {
+        inc = sqru *
+              (MAX(fabs(cxy[js]), MAX(hh * fabs(cpxy[js]), ONE / ewtxy[js])));
         cctmp = cxy[js];
         cxy[js] += inc;
-        fac = -ONE/inc;
+        fac = -ONE / inc;
 
         WebRates(xx, yy, cxy, perturb_rates, webdata);
 
         Pxycol = Pxy[js];
 
         for (is = 0; is < NUM_SPECIES; is++)
-          Pxycol[is] = (perturb_rates[is] - ratesxy[is])*fac;
+        {
+          Pxycol[is] = (perturb_rates[is] - ratesxy[is]) * fac;
+        }
 
-        if (js < 1) Pxycol[js] += cj;
+        if (js < 1) { Pxycol[js] += cj; }
 
         cxy[js] = cctmp;
       }
 
-      ret = SUNDlsMat_denseGETRF(Pxy, NUM_SPECIES, NUM_SPECIES, (webdata->pivot)[jx][jy]);
+      ret = SUNDlsMat_denseGETRF(Pxy, NUM_SPECIES, NUM_SPECIES,
+                                 (webdata->pivot)[jx][jy]);
 
-      if (ret != 0) return(1);
+      if (ret != 0) { return (1); }
     }
   }
 
-  return(0);
-
+  return (0);
 }
 
-
-static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
-                  N_Vector rr, N_Vector rvec, N_Vector zvec,
-                  realtype cj, realtype dalta, void *user_data)
+static int PSolve(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector rr,
+                  N_Vector rvec, N_Vector zvec, sunrealtype cj,
+                  sunrealtype dalta, void* user_data)
 {
-  realtype **Pxy, *zxy;
-  sunindextype *pivot;
+  sunrealtype **Pxy, *zxy;
+  sunindextype* pivot;
   sunindextype jx, jy;
   UserData webdata;
 
   jx = jy = 0;
 
-  webdata = (UserData) user_data;
+  webdata = (UserData)user_data;
 
   N_VScale(ONE, rvec, zvec);
 
-#pragma omp parallel for collapse(2) default(shared) private(jx, jy, zxy, Pxy, pivot) schedule(static) num_threads(webdata->nthreads)
-  for (jx = 0; jx < MX; jx++) {
-    for (jy = 0; jy <MY; jy++) {
-
-      zxy = IJ_Vptr(zvec, jx, jy);
-      Pxy = (webdata->PP)[jx][jy];
+#pragma omp parallel for collapse(2) default(shared) private(jx, jy, zxy, Pxy, \
+                                                               pivot)          \
+  schedule(static) num_threads(webdata->nthreads)
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
+      zxy   = IJ_Vptr(zvec, jx, jy);
+      Pxy   = (webdata->PP)[jx][jy];
       pivot = (webdata->pivot)[jx][jy];
       SUNDlsMat_denseGETRS(Pxy, NUM_SPECIES, pivot, zxy);
     }
   }
 
-  return(0);
-
+  return (0);
 }
 
-
 /*
  *--------------------------------------------------------------------
  * PRIVATE FUNCTIONS
@@ -534,42 +544,48 @@ static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
 static void InitUserData(UserData webdata)
 {
   sunindextype i, j, np;
-  realtype *a1,*a2, *a3, *a4, dx2, dy2;
+  sunrealtype *a1, *a2, *a3, *a4, dx2, dy2;
 
-  webdata->mx = MX;
-  webdata->my = MY;
-  webdata->ns = NUM_SPECIES;
-  webdata->np = NPREY;
-  webdata->dx = AX/(MX-1);
-  webdata->dy = AY/(MY-1);
-  webdata->Neq= NEQ;
+  webdata->mx  = MX;
+  webdata->my  = MY;
+  webdata->ns  = NUM_SPECIES;
+  webdata->np  = NPREY;
+  webdata->dx  = AX / (MX - 1);
+  webdata->dy  = AY / (MY - 1);
+  webdata->Neq = NEQ;
 
   /* Set up the coefficients a and b, and others found in the equations. */
-  np = webdata->np;
-  dx2 = (webdata->dx)*(webdata->dx); dy2 = (webdata->dy)*(webdata->dy);
+  np  = webdata->np;
+  dx2 = (webdata->dx) * (webdata->dx);
+  dy2 = (webdata->dy) * (webdata->dy);
 
-  for (i = 0; i < np; i++) {
+  for (i = 0; i < np; i++)
+  {
     a1 = &(acoef[i][np]);
-    a2 = &(acoef[i+np][0]);
+    a2 = &(acoef[i + np][0]);
     a3 = &(acoef[i][0]);
-    a4 = &(acoef[i+np][np]);
+    a4 = &(acoef[i + np][np]);
     /*  Fill in the portion of acoef in the four quadrants, row by row. */
-    for (j = 0; j < np; j++) {
-      *a1++ =  -GG;
-      *a2++ =   EE;
+    for (j = 0; j < np; j++)
+    {
+      *a1++ = -GG;
+      *a2++ = EE;
       *a3++ = ZERO;
       *a4++ = ZERO;
     }
 
     /* Reset the diagonal elements of acoef to -AA. */
-    acoef[i][i] = -AA; acoef[i+np][i+np] = -AA;
+    acoef[i][i]           = -AA;
+    acoef[i + np][i + np] = -AA;
 
     /* Set coefficients for b and diffusion terms. */
-    bcoef[i] = BB; bcoef[i+np] = -BB;
-    cox[i] = DPREY/dx2; cox[i+np] = DPRED/dx2;
-    coy[i] = DPREY/dy2; coy[i+np] = DPRED/dy2;
+    bcoef[i]      = BB;
+    bcoef[i + np] = -BB;
+    cox[i]        = DPREY / dx2;
+    cox[i + np]   = DPRED / dx2;
+    coy[i]        = DPREY / dy2;
+    coy[i + np]   = DPRED / dy2;
   }
-
 }
 
 /*
@@ -585,32 +601,37 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
                                UserData webdata)
 {
   sunindextype loc, yloc, is, jx, jy, np;
-  realtype xx, yy, xyfactor;
-  realtype *ccv, *cpv, *idv;
+  sunrealtype xx, yy, xyfactor;
+  sunrealtype *ccv, *cpv, *idv;
 
   ccv = NV_DATA_OMP(cc);
   cpv = NV_DATA_OMP(cp);
   idv = NV_DATA_OMP(id);
-  np = webdata->np;
+  np  = webdata->np;
 
   /* Loop over grid, load cc values and id values. */
-  for (jy = 0; jy < MY; jy++) {
-    yy = jy * webdata->dy;
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy   = jy * webdata->dy;
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
-      xx = jx * webdata->dx;
-      xyfactor = RCONST(16.0)*xx*(ONE-xx)*yy*(ONE-yy);
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx       = jx * webdata->dx;
+      xyfactor = SUN_RCONST(16.0) * xx * (ONE - xx) * yy * (ONE - yy);
       xyfactor *= xyfactor;
-      loc = yloc + NUM_SPECIES*jx;
+      loc = yloc + NUM_SPECIES * jx;
 
-      for (is = 0; is < NUM_SPECIES; is++) {
-        if (is < np) {
-          ccv[loc+is] = RCONST(10.0) + (realtype)(is+1) * xyfactor;
-          idv[loc+is] = ONE;
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
+        if (is < np)
+        {
+          ccv[loc + is] = SUN_RCONST(10.0) + (sunrealtype)(is + 1) * xyfactor;
+          idv[loc + is] = ONE;
         }
-        else {
-          ccv[loc+is] = RCONST(1.0e5);
-          idv[loc+is] = ZERO;
+        else
+        {
+          ccv[loc + is] = SUN_RCONST(1.0e5);
+          idv[loc + is] = ZERO;
         }
       }
     }
@@ -620,13 +641,13 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
   Fweb(ZERO, cc, cp, webdata);
 
   /* Set c' for predators to 0. */
-  for (jy = 0; jy < MY; jy++) {
+  for (jy = 0; jy < MY; jy++)
+  {
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
+    for (jx = 0; jx < MX; jx++)
+    {
       loc = yloc + NUM_SPECIES * jx;
-      for (is = np; is < NUM_SPECIES; is++) {
-        cpv[loc+is] = ZERO;
-      }
+      for (is = np; is < NUM_SPECIES; is++) { cpv[loc + is] = ZERO; }
     }
   }
 }
@@ -635,9 +656,10 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
  * Print first lines of output (problem description)
  */
 
-static void PrintHeader(int maxl, realtype rtol, realtype atol)
+static void PrintHeader(int maxl, sunrealtype rtol, sunrealtype atol)
 {
-  printf("\nidasFoodWeb_kry_omp: Predator-prey DAE OpenMP example problem using Krylov solver for IDAS \n\n");
+  printf("\nidasFoodWeb_kry_omp: Predator-prey DAE OpenMP example problem "
+         "using Krylov solver for IDAS \n\n");
   printf("Number of species ns: %d", NUM_SPECIES);
   printf("     Mesh dimensions: %d x %d", MX, MY);
   printf("     System size: %d\n", NEQ);
@@ -654,7 +676,6 @@ static void PrintHeader(int maxl, realtype rtol, realtype atol)
   printf("  t        bottom-left  top-right");
   printf("    | nst  k      h\n");
   printf("-----------------------------------------------------------\n\n");
-
 }
 
 /*
@@ -663,11 +684,11 @@ static void PrintHeader(int maxl, realtype rtol, realtype atol)
  * are printed for the bottom left and top right grid points only.
  */
 
-static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
+static void PrintOutput(void* ida_mem, N_Vector c, sunrealtype t)
 {
   int i, kused, retval;
   long int nst;
-  realtype *c_bl, *c_tr, hused;
+  sunrealtype *c_bl, *c_tr, hused;
 
   retval = IDAGetLastOrder(ida_mem, &kused);
   check_retval(&retval, "IDAGetLastOrder", 1);
@@ -676,24 +697,26 @@ static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
   retval = IDAGetLastStep(ida_mem, &hused);
   check_retval(&retval, "IDAGetLastStep", 1);
 
-  c_bl = IJ_Vptr(c,0,0);
-  c_tr = IJ_Vptr(c,MX-1,MY-1);
+  c_bl = IJ_Vptr(c, 0, 0);
+  c_tr = IJ_Vptr(c, MX - 1, MY - 1);
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n",
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4Le %12.4Le   |\n",c_bl[i],c_tr[i]);
+  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", t, c_bl[0], c_tr[0],
+         nst, kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+    printf("         %12.4Le %12.4Le   |\n", c_bl[i], c_tr[i]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", t, c_bl[0], c_tr[0], nst,
+         kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+  {
+    printf("         %12.4e %12.4e   |\n", c_bl[i], c_tr[i]);
+  }
 #else
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", t, c_bl[0], c_tr[0], nst,
+         kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+    printf("         %12.4e %12.4e   |\n", c_bl[i], c_tr[i]);
 #endif
 
   printf("\n");
@@ -703,7 +726,7 @@ static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
  * PrintFinalStats: Print final run data contained in iopt.
  */
 
-static void PrintFinalStats(void *ida_mem)
+static void PrintFinalStats(void* ida_mem)
 {
   long int nst, nre, sli, netf, nps, npevals, nrevalsLS;
   int retval;
@@ -731,7 +754,6 @@ static void PrintFinalStats(void *ida_mem)
   printf("Number of linear iterations           = %ld\n", sli);
   printf("Number of error test failures         = %ld\n", netf);
   printf("Number of precond solve fun called    = %ld\n", nps);
-
 }
 
 /*
@@ -741,53 +763,54 @@ static void PrintFinalStats(void *ida_mem)
  * The interaction term is computed by the function WebRates.
  */
 
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
-                 UserData webdata)
+static void Fweb(sunrealtype tcalc, N_Vector cc, N_Vector crate, UserData webdata)
 {
   sunindextype jx, jy, is, idyu, idyl, idxu, idxl;
-  realtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
+  sunrealtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
 
   /* Loop over grid points, evaluate interaction vector (length ns),
      form diffusion difference terms, and load crate.                    */
 
   jx = jy = is = 0;
 
-  for (jy = 0; jy < MY; jy++) {
-    yy = (webdata->dy) * jy ;
-    idyu = (jy!=MY-1) ? NSMX : -NSMX;
-    idyl = (jy!= 0  ) ? NSMX : -NSMX;
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy   = (webdata->dy) * jy;
+    idyu = (jy != MY - 1) ? NSMX : -NSMX;
+    idyl = (jy != 0) ? NSMX : -NSMX;
 
-    for (jx = 0; jx < MX; jx++) {
-      xx = (webdata->dx) * jx;
-      idxu = (jx!= MX-1) ?  NUM_SPECIES : -NUM_SPECIES;
-      idxl = (jx!=  0  ) ?  NUM_SPECIES : -NUM_SPECIES;
-      cxy = IJ_Vptr(cc,jx,jy);
-      ratesxy = IJ_Vptr(webdata->rates,jx,jy);
-      cratexy = IJ_Vptr(crate,jx,jy);
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx      = (webdata->dx) * jx;
+      idxu    = (jx != MX - 1) ? NUM_SPECIES : -NUM_SPECIES;
+      idxl    = (jx != 0) ? NUM_SPECIES : -NUM_SPECIES;
+      cxy     = IJ_Vptr(cc, jx, jy);
+      ratesxy = IJ_Vptr(webdata->rates, jx, jy);
+      cratexy = IJ_Vptr(crate, jx, jy);
 
       /* Get interaction vector at this grid point. */
       WebRates(xx, yy, cxy, ratesxy, webdata);
 
       /* Loop over species, do differencing, load crate segment. */
-#pragma omp parallel for default(shared) private(is, dcyli, dcyui, dcxli, dcxui) schedule(static) num_threads(webdata->nthreads)
-      for (is = 0; is < NUM_SPECIES; is++) {
-
+#pragma omp parallel for default(shared) private(is, dcyli, dcyui, dcxli, dcxui) \
+  schedule(static) num_threads(webdata->nthreads)
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
         /* Differencing in y. */
-        dcyli = *(cxy+is) - *(cxy - idyl + is) ;
-        dcyui = *(cxy + idyu + is) - *(cxy+is);
+        dcyli = *(cxy + is) - *(cxy - idyl + is);
+        dcyui = *(cxy + idyu + is) - *(cxy + is);
 
         /* Differencing in x. */
-        dcxli = *(cxy+is) - *(cxy - idxl + is);
-        dcxui = *(cxy + idxu +is) - *(cxy+is);
+        dcxli = *(cxy + is) - *(cxy - idxl + is);
+        dcxui = *(cxy + idxu + is) - *(cxy + is);
 
         /* Compute the crate values at (xx,yy). */
-        cratexy[is] = coy[is] * (dcyui - dcyli) +
-          cox[is] * (dcxui - dcxli) + ratesxy[is];
+        cratexy[is] = coy[is] * (dcyui - dcyli) + cox[is] * (dcxui - dcxli) +
+                      ratesxy[is];
 
       } /* End is loop */
-    } /* End of jx loop */
-  } /* End of jy loop */
-
+    }   /* End of jx loop */
+  }     /* End of jy loop */
 }
 
 /*
@@ -795,35 +818,38 @@ static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
  * At a given (x,y), evaluate the array of ns reaction terms R.
  */
 
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
-                     UserData webdata)
+static void WebRates(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                     sunrealtype* ratesxy, UserData webdata)
 {
   int is;
-  realtype fac;
+  sunrealtype fac;
 
   for (is = 0; is < NUM_SPECIES; is++)
+  {
     ratesxy[is] = dotprod(NUM_SPECIES, cxy, acoef[is]);
+  }
 
-  fac = ONE + ALPHA*xx*yy + BETA*sin(FOURPI*xx)*sin(FOURPI*yy);
+  fac = ONE + ALPHA * xx * yy + BETA * sin(FOURPI * xx) * sin(FOURPI * yy);
 
   for (is = 0; is < NUM_SPECIES; is++)
-    ratesxy[is] = cxy[is]*( bcoef[is]*fac + ratesxy[is] );
-
+  {
+    ratesxy[is] = cxy[is] * (bcoef[is] * fac + ratesxy[is]);
+  }
 }
 
 /*
- * dotprod: dot product routine for realtype arrays, for use by WebRates.
+ * dotprod: dot product routine for sunrealtype arrays, for use by WebRates.
  */
 
-static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
+static sunrealtype dotprod(sunindextype size, sunrealtype* x1, sunrealtype* x2)
 {
   sunindextype i;
-  realtype *xx1, *xx2, temp = ZERO;
-
-  xx1 = x1; xx2 = x2;
-  for (i = 0; i < size; i++) temp += (*xx1++) * (*xx2++);
-  return(temp);
+  sunrealtype *xx1, *xx2, temp = ZERO;
 
+  xx1 = x1;
+  xx2 = x2;
+  for (i = 0; i < size; i++) { temp += (*xx1++) * (*xx2++); }
+  return (temp);
 }
 
 /*
@@ -836,32 +862,35 @@ static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
  *            NULL pointer
  */
 
-static int check_retval(void *returnvalue, char *funcname, int opt)
+static int check_retval(void* returnvalue, char* funcname, int opt)
 {
-  int *retval;
+  int* retval;
 
-  if (opt == 0 && returnvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL)
+  {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-    fprintf(stderr,
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
+    fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1);
-  } else if (opt == 1) {
+    return (1);
+  }
+  else if (opt == 1)
+  {
     /* Check if retval < 0 */
-    retval = (int *) returnvalue;
-    if (*retval < 0) {
-      fprintf(stderr,
-              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+    retval = (int*)returnvalue;
+    if (*retval < 0)
+    {
+      fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
               funcname, *retval);
-      return(1);
+      return (1);
     }
-  } else if (opt == 2 && returnvalue == NULL) {
+  }
+  else if (opt == 2 && returnvalue == NULL)
+  {
     /* Check if function returned NULL pointer - no memory allocated */
-    fprintf(stderr,
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
+    fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1);
+    return (1);
   }
 
-  return(0);
+  return (0);
 }
