@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! -----------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -17,46 +17,44 @@
 
 module test_nvector_mpimanyvector
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use fnvector_mpimanyvector_mod
   use fnvector_serial_mod
   use test_utilities
   implicit none
   include "mpif.h"
 
-  integer(c_int), parameter  :: nsubvecs = 2
-  integer(c_long), parameter :: N1       = 100        ! individual vector length
-  integer(c_long), parameter :: N2       = 200        ! individual vector length
-  integer(c_int),  parameter :: nv       = 3          ! length of vector arrays
-  integer(c_long), parameter :: N        = N1 + N2    ! overall manyvector length
-  integer(c_int), target     :: comm = MPI_COMM_WORLD ! default MPI communicator
-  integer(c_int), pointer    :: commptr
-  integer(c_int)             :: nprocs                ! number of MPI processes
+  integer(c_int), parameter :: nsubvecs = 2
+  integer(c_int), parameter :: nv = 3 ! length of vector arrays
+  integer(kind=myindextype), parameter :: N1 = 100      ! individual vector length
+  integer(kind=myindextype), parameter :: N2 = 200      ! individual vector length
+  integer(kind=myindextype), parameter :: N = N1 + N2   ! overall manyvector length
+  integer(c_int), target :: comm = MPI_COMM_WORLD       ! default MPI communicator
+  integer(c_int) :: nprocs                              ! number of MPI processes
 
 contains
 
   integer function smoke_tests() result(ret)
     implicit none
 
-    integer(c_long)         :: lenrw(1), leniw(1)     ! real and int work space size
-    integer(c_long)         :: ival                   ! integer work value
-    type(c_ptr)             :: cptr                   ! c_ptr work value
-    real(c_double)          :: rval                   ! real work value
-    real(c_double)          :: x1data(N1), x2data(N2) ! vector data array
-    real(c_double), pointer :: xptr(:)                ! pointer to vector data array
-    real(c_double)          :: nvarr(nv)              ! array of nv constants to go with vector array
-    type(N_Vector), pointer :: x, y, z, tmp           ! N_Vectors
-    type(c_ptr)             :: subvecs                ! MPIManyVector subvectors
-    type(c_ptr)             :: xvecs, zvecs           ! C pointer to array of MPIManyVectors
+    integer(kind=myindextype) :: lenrw(1), leniw(1)     ! real and int work space size
+    integer(kind=myindextype) :: ival                   ! integer work value
+    real(c_double)            :: rval                   ! real work value
+    real(c_double)            :: x1data(N1), x2data(N2) ! vector data array
+    real(c_double), pointer   :: xptr(:)                ! pointer to vector data array
+    real(c_double)            :: nvarr(nv)              ! array of nv constants to go with vector array
+    type(N_Vector), pointer   :: x, y, z, tmp           ! N_Vectors
+    type(c_ptr)               :: subvecs                ! MPIManyVector subvectors
+    type(c_ptr)               :: xvecs, zvecs           ! C pointer to array of MPIManyVectors
 
     !===== Setup ====
-    subvecs = FN_VNewVectorArray(nsubvecs)
-    tmp  => FN_VMake_Serial(N1, x1data, sunctx)
+    subvecs = FN_VNewVectorArray(nsubvecs, sunctx)
+    tmp => FN_VMake_Serial(N1, x1data, sunctx)
     call FN_VSetVecAtIndexVectorArray(subvecs, 0, tmp)
-    tmp  => FN_VMake_Serial(N2, x2data, sunctx)
+    tmp => FN_VMake_Serial(N2, x2data, sunctx)
     call FN_VSetVecAtIndexVectorArray(subvecs, 1, tmp)
 
-    x => FN_VMake_MPIManyVector(MPI_COMM_WORLD, int(nsubvecs,8), subvecs, sunctx)
+    x => FN_VMake_MPIManyVector(comm, int(nsubvecs, myindextype), subvecs, sunctx)
     call FN_VConst(ONE, x)
     y => FN_VClone_MPIManyVector(x)
     call FN_VConst(ONE, y)
@@ -65,14 +63,14 @@ contains
 
     xvecs = FN_VCloneVectorArray(nv, x)
     zvecs = FN_VCloneVectorArray(nv, z)
-    nvarr = (/ ONE, ONE, ONE /)
+    nvarr = (/ONE, ONE, ONE/)
 
     !===== Test =====
 
     ! test generic vector functions
     ival = FN_VGetVectorID_MPIManyVector(x)
     call FN_VSpace_MPIManyVector(x, lenrw, leniw)
-    cptr = FN_VGetCommunicator(x)
+    ival = FN_VGetCommunicator(x)
     ival = FN_VGetLength_MPIManyVector(x)
 
     ! test standard vector operations
@@ -97,22 +95,23 @@ contains
     rval = FN_VMinQuotientLocal_MPIManyVector(x, y)
 
     ! test fused vector operations
-    ival = FN_VLinearCombination_MPIManyVector(nv, nvarr, xvecs, x)
-    ival = FN_VScaleAddMulti_MPIManyVector(nv, nvarr, x, xvecs, zvecs)
-    ival = FN_VDotProdMulti_MPIManyVector(nv, x, xvecs, nvarr)
+    ival = FN_VLinearCombination_MPIManyVector(int(nv, 4), nvarr, xvecs, x)
+    ival = FN_VScaleAddMulti_MPIManyVector(int(nv, 4), nvarr, x, xvecs, zvecs)
+    ival = FN_VDotProdMulti_MPIManyVector(int(nv, 4), x, xvecs, nvarr)
 
     ! test vector array operations
-    ival = FN_VLinearSumVectorArray_MPIManyVector(nv, ONE, xvecs, ONE, xvecs, zvecs)
-    ival = FN_VScaleVectorArray_MPIManyVector(nv, nvarr, xvecs, zvecs)
-    ival = FN_VConstVectorArray_MPIManyVector(nv, ONE, xvecs)
-    ival = FN_VWrmsNormVectorArray_MPIManyVector(nv, xvecs, xvecs, nvarr)
-    ival = FN_VWrmsNormMaskVectorArray_MPIManyVector(nv, xvecs, xvecs, x, nvarr)
+    ival = FN_VLinearSumVectorArray_MPIManyVector(int(nv, 4), ONE, xvecs, ONE, xvecs, zvecs)
+    ival = FN_VScaleVectorArray_MPIManyVector(int(nv, 4), nvarr, xvecs, zvecs)
+    ival = FN_VConstVectorArray_MPIManyVector(int(nv, 4), ONE, xvecs)
+    ival = FN_VWrmsNormVectorArray_MPIManyVector(int(nv, 4), xvecs, xvecs, nvarr)
+    ival = FN_VWrmsNormMaskVectorArray_MPIManyVector(int(nv, 4), xvecs, xvecs, x, nvarr)
 
     ! test the MPIManyVector specific operations
     ival = FN_VGetNumSubvectors_MPIManyVector(x)
-    xptr => FN_VGetSubvectorArrayPointer_MPIManyVector(x, ival-1)
-    ival = FN_VSetSubvectorArrayPointer_MPIManyVector(xptr, x, ival-1)
-    tmp  => FN_VGetSubvector_MPIManyVector(x, ival-1)
+    xptr => FN_VGetSubvectorArrayPointer_MPIManyVector(x, ival - 1)
+    ival = FN_VSetSubvectorArrayPointer_MPIManyVector(xptr, x, ival - 1)
+    ival = FN_VGetNumSubvectors_MPIManyVector(x)
+    tmp => FN_VGetSubvector_MPIManyVector(x, ival - 1)
 
     !==== Cleanup =====
     tmp => FN_VGetVecAtIndexVectorArray(subvecs, 0)
@@ -146,15 +145,15 @@ contains
     if (fails /= 0) then
       print *, '   FAILURE - MPI_COMM_RANK returned nonzero'
       stop 1
-    endif
+    end if
 
-    subvecs = FN_VNewVectorArray(nsubvecs)
-    tmp  => FN_VMake_Serial(N1, x1data, sunctx)
+    subvecs = FN_VNewVectorArray(nsubvecs, sunctx)
+    tmp => FN_VMake_Serial(N1, x1data, sunctx)
     call FN_VSetVecAtIndexVectorArray(subvecs, 0, tmp)
-    tmp  => FN_VMake_Serial(N2, x2data, sunctx)
+    tmp => FN_VMake_Serial(N2, x2data, sunctx)
     call FN_VSetVecAtIndexVectorArray(subvecs, 1, tmp)
 
-    x => FN_VMake_MPIManyVector(MPI_COMM_WORLD, int(nsubvecs,8), subvecs, sunctx)
+    x => FN_VMake_MPIManyVector(comm, int(nsubvecs, myindextype), subvecs, sunctx)
     call FN_VConst(ONE, x)
 
     !==== tests ====
@@ -173,24 +172,22 @@ contains
 
 end module
 
-
 integer(C_INT) function check_ans(ans, X, local_length) result(failure)
   use, intrinsic :: iso_c_binding
   use fnvector_mpimanyvector_mod
-  use fsundials_nvector_mod
   use test_utilities
   implicit none
 
-  real(C_DOUBLE)          :: ans
-  type(N_Vector)          :: X
-  type(N_Vector), pointer :: X0, X1
-  integer(C_LONG)         :: local_length, i, x0len, x1len
-  real(C_DOUBLE), pointer :: x0data(:), x1data(:)
+  real(C_DOUBLE)            :: ans
+  type(N_Vector)            :: X
+  type(N_Vector), pointer   :: X0, X1
+  integer(kind=myindextype) :: local_length, i, x0len, x1len
+  real(C_DOUBLE), pointer   :: x0data(:), x1data(:)
 
   failure = 0
 
-  X0 => FN_VGetSubvector_MPIManyVector(X, 0_8)
-  X1 => FN_VGetSubvector_MPIManyVector(X, 1_8)
+  X0 => FN_VGetSubvector_MPIManyVector(X, 0_myindextype)
+  X1 => FN_VGetSubvector_MPIManyVector(X, 1_myindextype)
   x0len = FN_VGetLength(X0)
   x1len = FN_VGetLength(X1)
   x0data => FN_VGetArrayPointer(X0)
@@ -199,13 +196,13 @@ integer(C_INT) function check_ans(ans, X, local_length) result(failure)
   if (local_length /= (x0len + x1len)) then
     failure = 1
     return
-  endif
+  end if
 
   do i = 1, x0len
     if (FNEQ(x0data(i), ans) > 0) then
       failure = failure + 1
     end if
-  enddo
+  end do
 
   do i = 1, x1len
     if (FNEQ(x1data(i), ans) > 0) then
@@ -214,10 +211,9 @@ integer(C_INT) function check_ans(ans, X, local_length) result(failure)
   end do
 end function check_ans
 
-
 logical function has_data(X) result(failure)
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use test_utilities
   implicit none
 
@@ -226,7 +222,6 @@ logical function has_data(X) result(failure)
   failure = .true.
 end function has_data
 
-
 program main
   !======== Inclusions ==========
   use, intrinsic :: iso_c_binding
@@ -242,26 +237,24 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_INIT returned nonzero'
     stop 1
-  endif
+  end if
 
   call MPI_Comm_rank(comm, myid, fails)
   if (fails /= 0) then
     print *, 'FAILURE: MPI_COMM_RANK returned nonzero, proc', myid
     stop 1
-  endif
-
-  commptr => comm
+  end if
 
   !============== Introduction =============
   if (myid == 0) print *, 'MPIManyVector N_Vector Fortran 2003 interface test'
 
-  call Test_Init(c_loc(commptr))
+  call Test_Init(comm)
 
   call MPI_Comm_size(comm, nprocs, fails)
   if (fails /= 0) then
     print *, 'FAILURE: MPI_COMM_SIZE returned nonzero, proc', myid
     stop 1
-  endif
+  end if
 
   fails = smoke_tests()
   if (fails /= 0) then
@@ -275,14 +268,14 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_BARRIER returned nonzero, proc', myid
     stop 1
-  endif
+  end if
 
   fails = unit_tests()
   if (fails /= 0) then
     print *, 'FAILURE: n unit tests failed, proc', myid
     stop 1
   else
-    if (myid == 0) print *,'    SUCCESS - all unit tests passed'
+    if (myid == 0) print *, '    SUCCESS - all unit tests passed'
   end if
 
   call Test_Finalize()
@@ -291,5 +284,5 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_FINALIZE returned nonzero, proc ', myid
     stop 1
-  endif
+  end if
 end program main
