@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! -----------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -17,34 +17,32 @@
 
 module test_nvector_parallel
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use fnvector_parallel_mod
   use test_utilities
   implicit none
   include "mpif.h"
 
-  integer(c_long), parameter :: local_length = 100    ! vector local length
-  integer(c_int),  parameter :: nv = 3                ! length of vector arrays
-  integer(c_int),  parameter :: ns = 2                ! number of vector arrays
+  integer(kind=myindextype), parameter :: local_length = 100    ! vector local length
+  integer(c_int), parameter :: nv = 3      ! length of vector arrays
+  integer(c_int), parameter :: ns = 2      ! number of vector arrays
 
-  integer(c_int), target  :: comm = MPI_COMM_WORLD ! default MPI communicator
-  integer(c_int), pointer :: commptr
-  integer(c_long)         :: global_length ! vector global_length
-  integer(c_int)          :: nprocs        ! number of MPI processes
-  contains
+  integer(c_int), target :: comm = MPI_COMM_WORLD ! default MPI communicator
+  integer(kind=myindextype) :: global_length      ! vector global_length
+  integer(c_int) :: nprocs                        ! number of MPI processes
+contains
 
   integer function smoke_tests() result(ret)
     implicit none
 
-    integer(c_long)         :: lenrw(1), leniw(1)  ! real and int work space size
-    integer(c_long)         :: ival                ! integer work value
-    type(c_ptr)             :: cptr                ! c_ptr work value
-    real(c_double)          :: rval                ! real work value
-    real(c_double)          :: xdata(local_length) ! vector data array
-    real(c_double), pointer :: xptr(:)             ! pointer to vector data array
-    real(c_double)          :: nvarr(nv)           ! array of nv constants to go with vector array
-    type(N_Vector), pointer :: x, y, z, tmp        ! N_Vectors
-    type(c_ptr)             :: xvecs, zvecs        ! C pointer to array of C pointers to N_Vectors
+    integer(kind=myindextype) :: lenrw(1), leniw(1)  ! real and int work space size
+    integer(c_long)           :: ival                ! integer work value
+    real(c_double)            :: rval                ! real work value
+    real(c_double)            :: xdata(local_length) ! vector data array
+    real(c_double), pointer   :: xptr(:)             ! pointer to vector data array
+    real(c_double)            :: nvarr(nv)           ! array of nv constants to go with vector array
+    type(N_Vector), pointer   :: x, y, z, tmp        ! N_Vectors
+    type(c_ptr)               :: xvecs, zvecs        ! C pointer to array of C pointers to N_Vectors
 
     !===== Setup ====
     x => FN_VMake_Parallel(comm, local_length, global_length, xdata, sunctx)
@@ -56,7 +54,7 @@ module test_nvector_parallel
 
     xvecs = FN_VCloneVectorArray(nv, x)
     zvecs = FN_VCloneVectorArray(nv, z)
-    nvarr = (/ ONE, ONE, ONE /)
+    nvarr = (/ONE, ONE, ONE/)
 
     !===== Test =====
 
@@ -75,7 +73,7 @@ module test_nvector_parallel
     call FN_VSpace_Parallel(x, lenrw, leniw)
     xptr => FN_VGetArrayPointer_Parallel(x)
     call FN_VSetArrayPointer_Parallel(xdata, x)
-    cptr = FN_VGetCommunicator_Parallel(x)
+    ival = FN_VGetCommunicator_Parallel(x)
     ival = FN_VGetLength_Parallel(x)
 
     ! test standard vector operations
@@ -100,16 +98,16 @@ module test_nvector_parallel
     rval = FN_VMinQuotient_Parallel(x, y)
 
     ! test fused vector operations
-    ival = FN_VLinearCombination_Parallel(nv, nvarr, xvecs, x)
-    ival = FN_VScaleAddMulti_Parallel(nv, nvarr, x, xvecs, zvecs)
-    ival = FN_VDotProdMulti_Parallel(nv, x, xvecs, nvarr)
+    ival = FN_VLinearCombination_Parallel(int(nv, 4), nvarr, xvecs, x)
+    ival = FN_VScaleAddMulti_Parallel(int(nv, 4), nvarr, x, xvecs, zvecs)
+    ival = FN_VDotProdMulti_Parallel(int(nv, 4), x, xvecs, nvarr)
 
     ! test vector array operations
-    ival = FN_VLinearSumVectorArray_Parallel(nv, ONE, xvecs, ONE, xvecs, zvecs)
-    ival = FN_VScaleVectorArray_Parallel(nv, nvarr, xvecs, zvecs)
-    ival = FN_VConstVectorArray_Parallel(nv, ONE, xvecs)
-    ival = FN_VWrmsNormVectorArray_Parallel(nv, xvecs, xvecs, nvarr)
-    ival = FN_VWrmsNormMaskVectorArray_Parallel(nv, xvecs, xvecs, x, nvarr)
+    ival = FN_VLinearSumVectorArray_Parallel(int(nv, 4), ONE, xvecs, ONE, xvecs, zvecs)
+    ival = FN_VScaleVectorArray_Parallel(int(nv, 4), nvarr, xvecs, zvecs)
+    ival = FN_VConstVectorArray_Parallel(int(nv, 4), ONE, xvecs)
+    ival = FN_VWrmsNormVectorArray_Parallel(int(nv, 4), xvecs, xvecs, nvarr)
+    ival = FN_VWrmsNormMaskVectorArray_Parallel(int(nv, 4), xvecs, xvecs, x, nvarr)
 
     !==== Cleanup =====
     call FN_VDestroy_Parallel(x)
@@ -138,7 +136,7 @@ module test_nvector_parallel
     if (fails /= 0) then
       print *, '   FAILURE - MPI_COMM_RANK returned nonzero'
       stop 1
-    endif
+    end if
 
     x => FN_VMake_Parallel(comm, local_length, global_length, xdata, sunctx)
     call FN_VConst(ONE, x)
@@ -155,17 +153,16 @@ module test_nvector_parallel
 
 end module
 
-
 integer(C_INT) function check_ans(ans, X, local_length) result(failure)
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use test_utilities
   implicit none
 
-  real(C_DOUBLE)          :: ans
-  type(N_Vector)          :: X
-  integer(C_LONG)         :: local_length, i
-  real(C_DOUBLE), pointer :: Xdata(:)
+  real(C_DOUBLE)            :: ans
+  type(N_Vector)            :: X
+  integer(kind=myindextype) :: local_length, i
+  real(C_DOUBLE), pointer   :: Xdata(:)
 
   failure = 0
 
@@ -177,10 +174,9 @@ integer(C_INT) function check_ans(ans, X, local_length) result(failure)
   end do
 end function check_ans
 
-
 logical function has_data(X) result(failure)
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use test_utilities
   implicit none
 
@@ -191,7 +187,6 @@ logical function has_data(X) result(failure)
   failure = associated(xptr)
 end function has_data
 
-
 program main
   !======== Inclusions ==========
   use, intrinsic :: iso_c_binding
@@ -207,26 +202,24 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_INIT returned nonzero'
     stop 1
-  endif
+  end if
 
   call MPI_Comm_rank(comm, myid, fails)
   if (fails /= 0) then
     print *, 'FAILURE: MPI_COMM_RANK returned nonzero, proc', myid
     stop 1
-  endif
-
-  commptr => comm
+  end if
 
   !============== Introduction =============
   if (myid == 0) print *, 'Parallel N_Vector Fortran 2003 interface test'
 
-  call Test_Init(c_loc(commptr))
+  call Test_Init(comm)
 
   call MPI_Comm_size(comm, nprocs, fails)
   if (fails /= 0) then
     print *, 'FAILURE: MPI_COMM_SIZE returned nonzero, proc', myid
     stop 1
-  endif
+  end if
   global_length = nprocs*local_length
 
   fails = smoke_tests()
@@ -241,14 +234,14 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_BARRIER returned nonzero, proc', myid
     stop 1
-  endif
+  end if
 
   fails = unit_tests()
   if (fails /= 0) then
     print *, 'FAILURE: n unit tests failed, proc', myid
     stop 1
   else
-    if (myid == 0) print *,'    SUCCESS - all unit tests passed'
+    if (myid == 0) print *, '    SUCCESS - all unit tests passed'
   end if
 
   call Test_Finalize()
@@ -257,6 +250,6 @@ program main
   if (fails /= 0) then
     print *, 'FAILURE: MPI_FINALIZE returned nonzero, proc ', myid
     stop 1
-  endif
+  end if
 
 end program main
