@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! -----------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -20,17 +20,14 @@ module test_fsunlinsol_band
   use test_utilities
   implicit none
 
-  integer(C_LONG), parameter :: N = 10
-  integer(C_LONG), parameter :: mu = 2
-  integer(C_LONG), parameter :: ml = 3
+  integer(kind=myindextype), parameter :: N = 10
+  integer(kind=myindextype), parameter :: mu = 2
+  integer(kind=myindextype), parameter :: ml = 3
 
 contains
 
-  integer(C_INT) function unit_tests() result(fails)
+  integer(c_int) function unit_tests() result(fails)
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
-    use fsundials_matrix_mod
-    use fsundials_linearsolver_mod
     use fnvector_serial_mod
     use fsunmatrix_band_mod
     use fsunlinsol_band_mod
@@ -39,14 +36,13 @@ contains
     implicit none
 
     type(SUNLinearSolver), pointer :: LS           ! test linear solver
-    type(SUNMatrix), pointer :: A                  ! test matrices
-    type(N_Vector),  pointer :: x, y, b            ! test vectors
-    real(C_DOUBLE),  pointer :: colj(:)            ! matrix column data
-    real(C_DOUBLE),  pointer :: xdata(:), Adata(:) ! data arrays
-    real(C_DOUBLE)           :: tmpr               ! temporary real value
-    integer(C_LONG)          :: j, k
-    integer(C_LONG)          :: smu, kstart, kend, offset
-    integer(C_INT)           :: tmp
+    type(SUNMatrix), pointer   :: A                  ! test matrices
+    type(N_Vector), pointer   :: x, y, b            ! test vectors
+    real(c_double), pointer   :: xdata(:), Adata(:) ! data arrays
+    real(c_double)             :: tmpr               ! temporary real value
+    integer(kind=myindextype) :: j, k
+    integer(kind=myindextype) :: smu, kstart, kend, offset
+    integer(c_int)             :: tmp
 
     fails = 0
     smu = 0
@@ -58,26 +54,25 @@ contains
 
     ! fill A matrix with uniform random data in [0, 1/N)
     Adata => FSUNBandMatrix_Data(A)
-    do j=1, N
-      offset = smu-mu+1 + j*(smu+ml+1)
-      colj(-mu:ml) => Adata(offset:mu+ml)
-      kstart = merge(-j, -mu, j < mu)
-      kend = merge(N-1-j, ml, j > N-1-ml)
-      do k=kstart, kend
+    do j = 1, N
+      offset = (j - 1)*(smu + ml + 1) + smu + 1 ! offset to diagonal
+      kstart = merge(-mu, -(j - 1), j > mu) ! above diagonal
+      kend = merge(N - j, ml, j > N - ml)  ! below diagonal
+      do k = kstart, kend
         call random_number(tmpr)
-        colj(k) = tmpr / N
+        Adata(offset + k) = tmpr/N
       end do
     end do
 
     ! fill x vector with uniform random data in [1, 2)
     xdata => FN_VGetArrayPointer(x)
-    do j=1, N
+    do j = 1, N
       call random_number(tmpr)
       xdata(j) = ONE + tmpr
     end do
 
     ! scale/shift matrix to ensure diagonal dominance
-    fails = FSUNMatScaleAddI(ONE/(mu+ml+1), A)
+    fails = FSUNMatScaleAddI(ONE/(mu + ml + 1), A)
     if (fails /= 0) then
       print *, 'FAIL:  FSUNMatScaleAddI failure'
       call FSUNMatDestroy(A)
@@ -104,7 +99,7 @@ contains
     ! run tests
     fails = fails + Test_FSUNLinSolInitialize(LS, 0)
     fails = fails + Test_FSUNLinSolSetup(LS, A, 0)
-    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, 100*UNIT_ROUNDOFF, 0)
+    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, 100*SUN_UNIT_ROUNDOFF, 0)
 
     fails = fails + Test_FSUNLinSolGetType(LS, SUNLINEARSOLVER_DIRECT, 0)
     fails = fails + Test_FSUNLinSolLastFlag(LS, 0)
@@ -121,16 +116,15 @@ contains
 
 end module
 
-integer(C_INT) function check_vector(X, Y, tol) result(failure)
+integer(c_int) function check_vector(X, Y, tol) result(failure)
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
   use test_utilities
-
   implicit none
+
   type(N_Vector)  :: x, y
-  real(C_DOUBLE)  :: tol, maxerr
-  integer(C_LONG) :: i, xlen, ylen
-  real(C_DOUBLE), pointer :: xdata(:), ydata(:)
+  real(c_double)  :: tol, maxerr
+  integer(kind=myindextype) :: i, xlen, ylen
+  real(c_double), pointer :: xdata(:), ydata(:)
 
   failure = 0
 
@@ -153,9 +147,9 @@ integer(C_INT) function check_vector(X, Y, tol) result(failure)
   if (failure > 0) then
     maxerr = ZERO
     do i = 1, xlen
-      maxerr = max(abs(xdata(i)-ydata(i))/abs(xdata(i)), maxerr)
+      maxerr = max(abs(xdata(i) - ydata(i))/abs(xdata(i)), maxerr)
     end do
-    write(*,'(A,E14.7,A,E14.7,A)') &
+    write (*, '(A,E14.7,A,E14.7,A)') &
       "FAIL: check_vector failure: maxerr = ", maxerr, "  (tol = ", FIVE*tol, ")"
   end if
 
@@ -168,19 +162,19 @@ program main
 
   !======== Declarations ========
   implicit none
-  integer(C_INT) :: fails = 0
+  integer(c_int) :: fails = 0
 
   !============== Introduction =============
   print *, 'Band SUNLinearSolver Fortran 2003 interface test'
 
-  call Test_Init(c_null_ptr)
+  call Test_Init(SUN_COMM_NULL)
 
   fails = unit_tests()
   if (fails /= 0) then
     print *, 'FAILURE: n unit tests failed'
     stop 1
   else
-    print *,'SUCCESS: all unit tests passed'
+    print *, 'SUCCESS: all unit tests passed'
   end if
 
   call Test_Finalize()
