@@ -2,7 +2,7 @@
 ! Programmer(s): Cody J. Balos @ LLNL
 ! -----------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2022, Lawrence Livermore National Security
+! Copyright (c) 2002-2024, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -21,27 +21,25 @@
 
 module test_fsunlinsol_pcg_serial
   use, intrinsic :: iso_c_binding
-  use fsundials_nvector_mod
+
   use test_utilities
   implicit none
 
-  integer(C_LONG), private, parameter :: N = 100
-  integer(C_INT),  private, parameter :: pretype = 1     ! Preconditioning type (1 or 2)
-  integer(C_INT),  private, parameter :: maxl    = 500   ! maxium Krylov subspace dimension (> 0)
-  real(C_DOUBLE),  private, parameter :: tol     = 1e-13 ! solver tolerance
+  integer(kind=myindextype), private, parameter :: N = 100
+  integer(c_int), private, parameter :: pretype = 1     ! Preconditioning type (1 or 2)
+  integer(c_int), private, parameter :: maxl = 500   ! maxium Krylov subspace dimension (> 0)
+  real(c_double), private, parameter :: tol = 1e-13 ! solver tolerance
 
   type, private :: UserData
-    integer(C_LONG) :: N
+    integer(kind=myindextype) :: N
     type(N_Vector), pointer  :: d, s
   end type
 
 contains
 
-  integer(C_INT) function unit_tests() result(fails)
+  integer(c_int) function unit_tests() result(fails)
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
-    use fsundials_matrix_mod
-    use fsundials_linearsolver_mod
+
     use fnvector_serial_mod
     use fsunlinsol_pcg_mod
     use test_sunlinsol
@@ -49,33 +47,33 @@ contains
     implicit none
 
     type(SUNLinearSolver), pointer :: LS         ! test linear solver
-    type(SUNMatrix),       pointer :: A          ! dummy SUNMatrix (set to null)
-    type(N_Vector),        pointer :: x, xhat, b ! test vectors
-    type(N_Vector),        pointer :: s2         ! dummy scaling vector (set to null)
-    type(UserData),        pointer :: probdata   ! problem data
-    real(C_DOUBLE),        pointer :: xdata(:)   ! x vector data
-    real(C_DOUBLE)                 :: tmpr       ! temporary real value
-    integer(C_LONG)                :: j
-    integer(C_INT)                 :: tmp
+    type(SUNMatrix), pointer :: A          ! dummy SUNMatrix (set to null)
+    type(N_Vector), pointer :: x, xhat, b ! test vectors
+    type(N_Vector), pointer :: s2         ! dummy scaling vector (set to null)
+    type(UserData), pointer :: probdata   ! problem data
+    real(c_double), pointer :: xdata(:)   ! x vector data
+    real(c_double)                 :: tmpr       ! temporary real value
+    integer(kind=myindextype)     :: j
+    integer(c_int)                 :: tmp
 
     ! setup
     fails = 0
 
-    A  => null()
+    A => null()
     s2 => null()
 
-    x    => FN_VNew_Serial(N, sunctx)
+    x => FN_VNew_Serial(N, sunctx)
     xhat => FN_VNew_Serial(N, sunctx)
-    b    => FN_VNew_Serial(N, sunctx)
+    b => FN_VNew_Serial(N, sunctx)
 
-    allocate(probdata)
+    allocate (probdata)
     probdata%N = N
     probdata%d => FN_VNew_Serial(N, sunctx)
     probdata%s => FN_VNew_Serial(N, sunctx)
 
     ! fill xhat vector with uniform random data in [1, 2)
     xdata => FN_VGetArrayPointer(xhat)
-    do j=1, N
+    do j = 1, N
       call random_number(tmpr)
       xdata(j) = ONE + tmpr
     end do
@@ -88,14 +86,14 @@ contains
 
     ! run initialization tests
     fails = fails + Test_FSUNLinSolGetType(LS, SUNLINEARSOLVER_ITERATIVE, 0)
-    fails = fails + Test_FSUNLinSolSetATimes(LS, c_loc(probdata),&
+    fails = fails + Test_FSUNLinSolSetATimes(LS, c_loc(probdata), &
                                              c_funloc(ATimes), 0)
-    fails = fails + Test_FSUNLinSolSetPreconditioner(LS,&
-                                                     c_loc(probdata),&
-                                                     c_funloc(PSetup),&
-                                                     c_funloc(PSolve),&
+    fails = fails + Test_FSUNLinSolSetPreconditioner(LS, &
+                                                     c_loc(probdata), &
+                                                     c_funloc(PSetup), &
+                                                     c_funloc(PSolve), &
                                                      0)
-    fails = fails + Test_FSUNLinSolSetScalingVectors(LS, probdata%s,&
+    fails = fails + Test_FSUNLinSolSetScalingVectors(LS, probdata%s, &
                                                      s2, 0)
     fails = fails + Test_FSUNLinSolInitialize(LS, 0)
     fails = fails + Test_FSUNLinSolSpace(LS, 0)
@@ -123,14 +121,13 @@ contains
     end if
 
     ! Run tests with this setup
-    fails = fails + FSUNLinSol_PCGSetPrecType(LS, SUN_PREC_NONE);
-    fails = fails + Test_FSUNLinSolSetup(LS, A, 0);
-    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0);
-    fails = fails + Test_FSUNLinSolLastFlag(LS, 0);
-    fails = fails + Test_FSUNLinSolNumIters(LS, 0);
-    fails = fails + Test_FSUNLinSolResNorm(LS, 0);
-    fails = fails + Test_FSUNLinSolResid(LS, 0);
-
+    fails = fails + FSUNLinSol_PCGSetPrecType(LS, SUN_PREC_NONE); 
+    fails = fails + Test_FSUNLinSolSetup(LS, A, 0); 
+    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0); 
+    fails = fails + Test_FSUNLinSolLastFlag(LS, 0); 
+    fails = fails + Test_FSUNLinSolNumIters(LS, 0); 
+    fails = fails + Test_FSUNLinSolResNorm(LS, 0); 
+    fails = fails + Test_FSUNLinSolResid(LS, 0); 
     if (fails /= 0) then
       print *, 'FAIL: FSUNLinSol_PCG module, problem 1'
     else
@@ -154,14 +151,13 @@ contains
     end if
 
     ! Run tests with this setup
-    fails = fails + FSUNLinSol_PCGSetPrecType(LS, pretype);
-    fails = fails + Test_FSUNLinSolSetup(LS, A, 0);
-    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0);
-    fails = fails + Test_FSUNLinSolLastFlag(LS, 0);
-    fails = fails + Test_FSUNLinSolNumIters(LS, 0);
-    fails = fails + Test_FSUNLinSolResNorm(LS, 0);
-    fails = fails + Test_FSUNLinSolResid(LS, 0);
-
+    fails = fails + FSUNLinSol_PCGSetPrecType(LS, pretype); 
+    fails = fails + Test_FSUNLinSolSetup(LS, A, 0); 
+    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0); 
+    fails = fails + Test_FSUNLinSolLastFlag(LS, 0); 
+    fails = fails + Test_FSUNLinSolNumIters(LS, 0); 
+    fails = fails + Test_FSUNLinSolResNorm(LS, 0); 
+    fails = fails + Test_FSUNLinSolResid(LS, 0); 
     if (fails /= 0) then
       print *, 'FAIL: FSUNLinSol_PCG module, problem 2'
     else
@@ -173,7 +169,7 @@ contains
 
     ! set scaling vectors
     xdata => FN_VGetArrayPointer(probdata%s)
-    do j=1, N
+    do j = 1, N
       call random_number(tmpr)
       xdata(j) = ONE + 1000.0d0*tmpr
     end do
@@ -189,14 +185,13 @@ contains
     end if
 
     ! Run tests with this setup
-    fails = fails + FSUNLinSol_PCGSetPrecType(LS, SUN_PREC_NONE);
-    fails = fails + Test_FSUNLinSolSetup(LS, A, 0);
-    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0);
-    fails = fails + Test_FSUNLinSolLastFlag(LS, 0);
-    fails = fails + Test_FSUNLinSolNumIters(LS, 0);
-    fails = fails + Test_FSUNLinSolResNorm(LS, 0);
-    fails = fails + Test_FSUNLinSolResid(LS, 0);
-
+    fails = fails + FSUNLinSol_PCGSetPrecType(LS, SUN_PREC_NONE); 
+    fails = fails + Test_FSUNLinSolSetup(LS, A, 0); 
+    fails = fails + Test_FSUNLinSolSolve(LS, A, x, b, tol, 0); 
+    fails = fails + Test_FSUNLinSolLastFlag(LS, 0); 
+    fails = fails + Test_FSUNLinSolNumIters(LS, 0); 
+    fails = fails + Test_FSUNLinSolResNorm(LS, 0); 
+    fails = fails + Test_FSUNLinSolResid(LS, 0); 
     if (fails /= 0) then
       print *, 'FAIL: FSUNLinSol_PCG module, problem 3'
     else
@@ -211,22 +206,22 @@ contains
     call FN_VDestroy(b)
     call FN_VDestroy(probdata%d)
     call FN_VDestroy(probdata%s)
-    deallocate(probdata)
+    deallocate (probdata)
 
   end function unit_tests
 
-  integer(C_INT) function ATimes(udata, vvec, zvec) result(ret) bind(C)
+  integer(c_int) function ATimes(udata, vvec, zvec) result(ret) bind(C)
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
+
     use test_utilities
 
     implicit none
 
-    type(C_PTR), value :: udata
+    type(c_ptr), value :: udata
     type(N_Vector) :: vvec, zvec
     type(UserData), pointer :: probdata
-    real(C_DOUBLE), pointer :: v(:), z(:), s(:)
-    integer(C_LONG) :: i, N
+    real(c_double), pointer :: v(:), z(:), s(:)
+    integer(c_long) :: i, N
 
     call c_f_pointer(udata, probdata)
 
@@ -239,37 +234,37 @@ contains
     z(1) = (FIVE*v(1)/s(1) - v(2)/s(2))/s(1)
 
     ! iterate through interior of local domain, performing product
-    do i = 2, N-1
-      z(i) = (-v(i-1)/s(i-1) + FIVE*v(i)/s(i) - v(i+1)/s(i+1))/s(i)
+    do i = 2, N - 1
+      z(i) = (-v(i - 1)/s(i - 1) + FIVE*v(i)/s(i) - v(i + 1)/s(i + 1))/s(i)
     end do
 
     ! perform product at the right domain boundary (note: v is zero at the boundary)
-    z(N) = (-v(N-1)/s(N-1) + FIVE*v(N)/s(N))/s(N)
+    z(N) = (-v(N - 1)/s(N - 1) + FIVE*v(N)/s(N))/s(N)
 
     ret = 0
   end function ATimes
 
-  integer(C_INT) function PSetup(udata) result(ret) bind(C)
+  integer(c_int) function PSetup(udata) result(ret) bind(C)
     use, intrinsic :: iso_c_binding
-    type(C_PTR), value :: udata
+    type(c_ptr), value :: udata
     ret = 0
   end function PSetup
 
-  integer(C_INT) function PSolve(udata, rvec, zvec, tol, lr) &
-      result(ret) bind(C)
+  integer(c_int) function PSolve(udata, rvec, zvec, tol, lr) &
+    result(ret) bind(C)
     use, intrinsic :: iso_c_binding
-    use fsundials_nvector_mod
+
     use test_utilities
 
     implicit none
 
-    type(C_PTR),    value   :: udata
+    type(c_ptr), value   :: udata
     type(N_Vector)          :: rvec, zvec
-    real(C_DOUBLE)          :: tol
-    integer(C_INT)          :: lr
+    real(c_double)          :: tol
+    integer(c_int)          :: lr
     type(UserData), pointer :: probdata
-    real(C_DOUBLE), pointer :: r(:), z(:), d(:), s(:)
-    integer(C_LONG)         :: i, N
+    real(c_double), pointer :: r(:), z(:), d(:), s(:)
+    integer(c_long)         :: i, N
 
     call c_f_pointer(udata, probdata)
 
@@ -279,8 +274,8 @@ contains
     s => FN_VGetArrayPointer(probdata%s)
     N = probdata%N
 
-    do i=1, N
-      z(i) = s(i) * s(i) * r(i) / d(i)
+    do i = 1, N
+      z(i) = s(i)*s(i)*r(i)/d(i)
     end do
 
     ret = 0
@@ -288,16 +283,16 @@ contains
 
 end module
 
-integer(C_INT) function check_vector(X, Y, tol) result(failure)
+integer(c_int) function check_vector(X, Y, tol) result(failure)
   use, intrinsic :: iso_c_binding
   use test_fsunlinsol_pcg_serial
   use test_utilities
 
   implicit none
   type(N_Vector)  :: x, y
-  real(C_DOUBLE)  :: tol, maxerr
-  integer(C_LONG) :: i, xlen, ylen
-  real(C_DOUBLE), pointer :: xdata(:), ydata(:)
+  real(c_double)  :: tol, maxerr
+  integer(c_long) :: i, xlen, ylen
+  real(c_double), pointer :: xdata(:), ydata(:)
 
   failure = 0
 
@@ -320,9 +315,9 @@ integer(C_INT) function check_vector(X, Y, tol) result(failure)
   if (failure > 0) then
     maxerr = ZERO
     do i = 1, xlen
-      maxerr = max(abs(xdata(i)-ydata(i))/abs(xdata(i)), maxerr)
+      maxerr = max(abs(xdata(i) - ydata(i))/abs(xdata(i)), maxerr)
     end do
-    write(*,'(A,E14.7,A,E14.7,A)') &
+    write (*, '(A,E14.7,A,E14.7,A)') &
       "FAIL: check_vector failure: maxerr = ", maxerr, "  (tol = ", FIVE*tol, ")"
   end if
 
@@ -335,20 +330,20 @@ program main
 
   !======== Declarations ========
   implicit none
-  integer(C_INT) :: fails = 0
+  integer(c_int) :: fails = 0
 
   !============== Introduction =============
   print *, 'PCG SUNLinearSolver Fortran 2003 interface test'
   print *, ''
 
-  call Test_Init(c_null_ptr)
+  call Test_Init(SUN_COMM_NULL)
 
   fails = unit_tests()
   if (fails /= 0) then
     print *, 'FAILURE: ', fails, ' unit tests failed'
     stop 1
   else
-    print *,'SUCCESS: all unit tests passed'
+    print *, 'SUCCESS: all unit tests passed'
   end if
 
   call Test_Finalize()
