@@ -3,7 +3,7 @@
  * Programmer(s): Daniel Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -17,67 +17,74 @@
  * -----------------------------------------------------------------
  */
 
+#include <nvector/nvector_serial.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <sundials/sundials_math.h>
 #include <sundials/sundials_types.h>
 #include <sunlinsol/sunlinsol_superlumt.h>
 #include <sunmatrix/sunmatrix_dense.h>
 #include <sunmatrix/sunmatrix_sparse.h>
-#include <nvector/nvector_serial.h>
-#include <sundials/sundials_math.h>
-#include "test_sunlinsol.h"
 
+#include "test_sunlinsol.h"
 
 /* ----------------------------------------------------------------------
  * SUNLinSol_SuperLUMT Linear Solver Testing Routine
  * --------------------------------------------------------------------*/
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
-  int             fails = 0;          /* counter for test failures  */
-  sunindextype    N;                  /* matrix columns, rows       */
-  SUNLinearSolver LS;                 /* linear solver object       */
-  SUNMatrix       A, B;               /* test matrices              */
-  N_Vector        x, y, b;            /* test vectors               */
-  realtype        *matdata, *xdata;
-  int             mattype, num_threads, print_timing;
-  sunindextype    i, j, k;
-  SUNContext      sunctx;
+  int fails = 0;      /* counter for test failures  */
+  sunindextype N;     /* matrix columns, rows       */
+  SUNLinearSolver LS; /* linear solver object       */
+  SUNMatrix A, B;     /* test matrices              */
+  N_Vector x, y, b;   /* test vectors               */
+  sunrealtype *matdata, *xdata;
+  int mattype, num_threads, print_timing;
+  sunindextype i, j, k;
+  SUNContext sunctx;
 
-  if (SUNContext_Create(NULL, &sunctx)) {
+  if (SUNContext_Create(SUN_COMM_NULL, &sunctx))
+  {
     printf("ERROR: SUNContext_Create failed\n");
-    return(-1);
+    return (-1);
   }
 
   /* check input and set matrix dimensions */
-  if (argc < 5){
-    printf("ERROR: FOUR (4) Inputs required: matrix size, matrix type (0 = CSC / 1 = CSR), num_threads, print timing \n");
-    return(-1);
+  if (argc < 5)
+  {
+    printf("ERROR: FOUR (4) Inputs required: matrix size, matrix type (0 = CSC "
+           "/ 1 = CSR), num_threads, print timing \n");
+    return (-1);
   }
 
-  N = (sunindextype) atol(argv[1]);
-  if (N <= 0) {
+  N = (sunindextype)atol(argv[1]);
+  if (N <= 0)
+  {
     printf("ERROR: matrix size must be a positive integer \n");
-    return(-1);
+    return (-1);
   }
 
   mattype = atoi(argv[2]);
-  if ((mattype != 0) && (mattype != 1)) {
+  if ((mattype != 0) && (mattype != 1))
+  {
     printf("ERROR: matrix type must be 0 or 1 \n");
-    return(-1);
+    return (-1);
   }
   mattype = (mattype == 0) ? CSC_MAT : CSR_MAT;
 
   num_threads = atoi(argv[3]);
-  if (num_threads <= 0) {
+  if (num_threads <= 0)
+  {
     printf("ERROR: number_threads must be a positive integer \n");
-    return(-1);
+    return (-1);
   }
 
   print_timing = atoi(argv[4]);
   SetTiming(print_timing);
 
-  printf("\nSuperLUMT linear solver test: size %ld, type %i, num_threads %i\n\n",
-         (long int) N, mattype, num_threads);
+  printf("\nSuperLUMT linear solver test: size %ld, type %i, num_threads "
+         "%i\n\n",
+         (long int)N, mattype, num_threads);
 
   /* Create matrices and vectors */
   B = SUNDenseMatrix(N, N, sunctx);
@@ -86,24 +93,28 @@ int main(int argc, char *argv[])
   b = N_VNew_Serial(N, sunctx);
 
   /* Fill matrix with uniform random data in [0,1/N] */
-  for (k=0; k<5*N; k++) {
-    i = rand() % N;
-    j = rand() % N;
-    matdata = SUNDenseMatrix_Column(B,j);
-    matdata[i] = (realtype) rand() / (realtype) RAND_MAX / N;
+  for (k = 0; k < 5 * N; k++)
+  {
+    i          = rand() % N;
+    j          = rand() % N;
+    matdata    = SUNDenseMatrix_Column(B, j);
+    matdata[i] = (sunrealtype)rand() / (sunrealtype)RAND_MAX / N;
   }
 
   /* Add identity to matrix */
   fails = SUNMatScaleAddI(ONE, B);
-  if (fails) {
+  if (fails)
+  {
     printf("FAIL: SUNLinSol SUNMatScaleAddI failure\n");
-    return(1);
+    return (1);
   }
 
   /* Fill x vector with uniform random data in [0,1] */
   xdata = N_VGetArrayPointer(x);
-  for (i=0; i<N; i++)
-    xdata[i] = (realtype) rand() / (realtype) RAND_MAX;
+  for (i = 0; i < N; i++)
+  {
+    xdata[i] = (sunrealtype)rand() / (sunrealtype)RAND_MAX;
+  }
 
   /* Create sparse matrix from dense, and destroy B */
   A = SUNSparseFromDenseMatrix(B, ZERO, mattype);
@@ -114,9 +125,10 @@ int main(int argc, char *argv[])
 
   /* create right-hand side vector for linear solve */
   fails = SUNMatMatvec(A, x, b);
-  if (fails) {
+  if (fails)
+  {
     printf("FAIL: SUNLinSol SUNMatMatvec failure\n");
-    return(1);
+    return (1);
   }
 
   /* Create SuperLUMT linear solver */
@@ -125,7 +137,7 @@ int main(int argc, char *argv[])
   /* Run Tests */
   fails += Test_SUNLinSolInitialize(LS, 0);
   fails += Test_SUNLinSolSetup(LS, A, 0);
-  fails += Test_SUNLinSolSolve(LS, A, x, b, 1000*UNIT_ROUNDOFF, SUNTRUE, 0);
+  fails += Test_SUNLinSolSolve(LS, A, x, b, 1000 * SUN_UNIT_ROUNDOFF, SUNTRUE, 0);
 
   fails += Test_SUNLinSolGetType(LS, SUNLINEARSOLVER_DIRECT, 0);
   fails += Test_SUNLinSolGetID(LS, SUNLINEARSOLVER_SUPERLUMT, 0);
@@ -133,19 +145,19 @@ int main(int argc, char *argv[])
   fails += Test_SUNLinSolSpace(LS, 0);
 
   /* Print result */
-  if (fails) {
+  if (fails)
+  {
     printf("FAIL: SUNLinSol module failed %i tests \n \n", fails);
     printf("\nA =\n");
-    SUNSparseMatrix_Print(A,stdout);
+    SUNSparseMatrix_Print(A, stdout);
     printf("\nx (original) =\n");
     N_VPrint_Serial(y);
     printf("\nb =\n");
     N_VPrint_Serial(b);
     printf("\nx (computed) =\n");
     N_VPrint_Serial(x);
-  } else {
-    printf("SUCCESS: SUNLinSol module passed all tests \n \n");
   }
+  else { printf("SUCCESS: SUNLinSol module passed all tests \n \n"); }
 
   /* Free solver, matrix and vectors */
   SUNLinSolFree(LS);
@@ -155,43 +167,45 @@ int main(int argc, char *argv[])
   N_VDestroy(b);
   SUNContext_Free(&sunctx);
 
-  return(fails);
+  return (fails);
 }
 
 /* ----------------------------------------------------------------------
  * Implementation-specific 'check' routines
  * --------------------------------------------------------------------*/
-int check_vector(N_Vector X, N_Vector Y, realtype tol)
+int check_vector(N_Vector X, N_Vector Y, sunrealtype tol)
 {
   int failure = 0;
   sunindextype i, local_length, maxloc;
-  realtype *Xdata, *Ydata, maxerr;
+  sunrealtype *Xdata, *Ydata, maxerr;
 
-  Xdata = N_VGetArrayPointer(X);
-  Ydata = N_VGetArrayPointer(Y);
+  Xdata        = N_VGetArrayPointer(X);
+  Ydata        = N_VGetArrayPointer(Y);
   local_length = N_VGetLength_Serial(X);
 
   /* check vector data */
-  for(i=0; i < local_length; i++)
+  for (i = 0; i < local_length; i++)
+  {
     failure += SUNRCompareTol(Xdata[i], Ydata[i], tol);
+  }
 
-  if (failure > ZERO) {
+  if (failure > ZERO)
+  {
     maxerr = ZERO;
     maxloc = -1;
-    for(i=0; i < local_length; i++) {
-      if (SUNRabs(Xdata[i]-Ydata[i]) >  maxerr) {
-        maxerr = SUNRabs(Xdata[i]-Ydata[i]);
+    for (i = 0; i < local_length; i++)
+    {
+      if (SUNRabs(Xdata[i] - Ydata[i]) > maxerr)
+      {
+        maxerr = SUNRabs(Xdata[i] - Ydata[i]);
         maxloc = i;
       }
     }
-    printf("check err failure: maxerr = %g at loc %li (tol = %g)\n",
-	   maxerr, (long int) maxloc, tol);
-    return(1);
+    printf("check err failure: maxerr = %g at loc %li (tol = %g)\n", maxerr,
+           (long int)maxloc, tol);
+    return (1);
   }
-  else
-    return(0);
+  else { return (0); }
 }
 
-void sync_device()
-{
-}
+void sync_device() {}
