@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -20,12 +20,10 @@
 
 #include <cstdio>
 #include <stdexcept>
-#include <CL/sycl.hpp>
+#include <sycl/sycl.hpp>
 
-namespace sundials
-{
-namespace sycl
-{
+namespace sundials {
+namespace sycl {
 
 class ExecPolicy
 {
@@ -33,10 +31,10 @@ public:
   virtual size_t gridSize(size_t numWorkUnits = 0, size_t blockDim = 0) const = 0;
   virtual size_t blockSize(size_t numWorkUnits = 0, size_t gridDim = 0) const = 0;
   virtual ExecPolicy* clone() const = 0;
+
   virtual ~ExecPolicy() {}
 };
 
-
 /*
  * A kernel execution policy that maps each thread to a work unit.
  * The number of threads per block (blockSize) can be set to anything.
@@ -46,9 +44,7 @@ public:
 class ThreadDirectExecPolicy : public ExecPolicy
 {
 public:
-  ThreadDirectExecPolicy(const size_t blockDim)
-    : blockDim_(blockDim)
-  {}
+  ThreadDirectExecPolicy(const size_t blockDim) : blockDim_(blockDim) {}
 
   ThreadDirectExecPolicy(const ThreadDirectExecPolicy& ex)
     : blockDim_(ex.blockDim_)
