@@ -1,10 +1,10 @@
 /*
- * ----------------------------------------------------------------- 
+ * -----------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *     Michael Wittman, Alan C. Hindmarsh and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2021, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -21,10 +21,10 @@
 #define _CVBBDPRE_IMPL_H
 
 #include <cvode/cvode_bbdpre.h>
-#include <sunmatrix/sunmatrix_band.h>
 #include <sunlinsol/sunlinsol_band.h>
+#include <sunmatrix/sunmatrix_band.h>
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
@@ -32,11 +32,11 @@ extern "C" {
   Type: CVBBDPrecData
   -----------------------------------------------------------------*/
 
-typedef struct CVBBDPrecDataRec {
-
+typedef struct CVBBDPrecDataRec
+{
   /* passed by user to CVBBDPrecInit and used by PrecSetup/PrecSolve */
   sunindextype mudq, mldq, mukeep, mlkeep;
-  realtype dqrely;
+  sunrealtype dqrely;
   CVLocalFn gloc;
   CVCommFn cfn;
 
@@ -59,22 +59,26 @@ typedef struct CVBBDPrecDataRec {
   long int nge;
 
   /* pointer to cvode_mem */
-  void *cvode_mem;
+  void* cvode_mem;
 
-} *CVBBDPrecData;
+}* CVBBDPrecData;
 
 /*-----------------------------------------------------------------
   CVBBDPRE error messages
   -----------------------------------------------------------------*/
 
-#define MSGBBD_MEM_NULL    "Integrator memory is NULL."
-#define MSGBBD_LMEM_NULL   "Linear solver memory is NULL. One of the SPILS linear solvers must be attached."
+#define MSGBBD_MEM_NULL "Integrator memory is NULL."
+#define MSGBBD_LMEM_NULL                                                   \
+  "Linear solver memory is NULL. One of the SPILS linear solvers must be " \
+  "attached."
 #define MSGBBD_MEM_FAIL    "A memory request failed."
 #define MSGBBD_BAD_NVECTOR "A required vector operation is not implemented."
 #define MSGBBD_SUNMAT_FAIL "An error arose from a SUNBandMatrix routine."
 #define MSGBBD_SUNLS_FAIL  "An error arose from a SUNBandLinearSolver routine."
-#define MSGBBD_PMEM_NULL   "BBD peconditioner memory is NULL. CVBBDPrecInit must be called."
-#define MSGBBD_FUNC_FAILED "The gloc or cfn routine failed in an unrecoverable manner."
+#define MSGBBD_PMEM_NULL \
+  "BBD peconditioner memory is NULL. CVBBDPrecInit must be called."
+#define MSGBBD_FUNC_FAILED \
+  "The gloc or cfn routine failed in an unrecoverable manner."
 
 #ifdef __cplusplus
 }
