@@ -4,7 +4,7 @@
  *                Radu Serban, Cody J. Balos @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -23,42 +23,17 @@
 #include "cvode_diag_impl.h"
 #include "cvode_impl.h"
 
-#ifdef SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS
-extern
-int cvDiagSetup_formY(const realtype h,
-                      const realtype r,
-                      const N_Vector fpred,
-                      const N_Vector zn1,
-                      const N_Vector ypred,
-                      N_Vector ftemp,
-                      N_Vector y);
-
-extern
-int cvDiagSetup_buildM(const realtype fract,
-                       const realtype uround,
-                       const realtype h,
-                       const N_Vector ftemp,
-                       const N_Vector fpred,
-                       const N_Vector ewt,
-                       N_Vector bit,
-                       N_Vector bitcomp,
-                       N_Vector y,
-                       N_Vector M);
-
-int cvDiagSolve_updateM(const realtype r, N_Vector M);
-#endif
-
 /* Other Constants */
 
-#define FRACT RCONST(0.1)
-#define ONE   RCONST(1.0)
+#define FRACT SUN_RCONST(0.1)
+#define ONE   SUN_RCONST(1.0)
 
 /* CVDIAG linit, lsetup, lsolve, and lfree routines */
 
 static int CVDiagInit(CVodeMem cv_mem);
 
 static int CVDiagSetup(CVodeMem cv_mem, int convfail, N_Vector ypred,
-                       N_Vector fpred, booleantype *jcurPtr, N_Vector vtemp1,
+                       N_Vector fpred, sunbooleantype* jcurPtr, N_Vector vtemp1,
                        N_Vector vtemp2, N_Vector vtemp3);
 
 static int CVDiagSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
@@ -68,24 +43,24 @@ static int CVDiagFree(CVodeMem cv_mem);
 
 /* Readability Replacements */
 
-#define lrw1      (cv_mem->cv_lrw1)
-#define liw1      (cv_mem->cv_liw1)
-#define f         (cv_mem->cv_f)
-#define uround    (cv_mem->cv_uround)
-#define tn        (cv_mem->cv_tn)
-#define h         (cv_mem->cv_h)
-#define rl1       (cv_mem->cv_rl1)
-#define gamma     (cv_mem->cv_gamma)
-#define ewt       (cv_mem->cv_ewt)
-#define nfe       (cv_mem->cv_nfe)
-#define zn        (cv_mem->cv_zn)
-#define linit     (cv_mem->cv_linit)
-#define lsetup    (cv_mem->cv_lsetup)
-#define lsolve    (cv_mem->cv_lsolve)
-#define lfree     (cv_mem->cv_lfree)
-#define lmem      (cv_mem->cv_lmem)
-#define vec_tmpl  (cv_mem->cv_tempv)
-#define setupNonNull   (cv_mem->cv_setupNonNull)
+#define lrw1         (cv_mem->cv_lrw1)
+#define liw1         (cv_mem->cv_liw1)
+#define f            (cv_mem->cv_f)
+#define uround       (cv_mem->cv_uround)
+#define tn           (cv_mem->cv_tn)
+#define h            (cv_mem->cv_h)
+#define rl1          (cv_mem->cv_rl1)
+#define gamma        (cv_mem->cv_gamma)
+#define ewt          (cv_mem->cv_ewt)
+#define nfe          (cv_mem->cv_nfe)
+#define zn           (cv_mem->cv_zn)
+#define linit        (cv_mem->cv_linit)
+#define lsetup       (cv_mem->cv_lsetup)
+#define lsolve       (cv_mem->cv_lsolve)
+#define lfree        (cv_mem->cv_lfree)
+#define lmem         (cv_mem->cv_lmem)
+#define vec_tmpl     (cv_mem->cv_tempv)
+#define setupNonNull (cv_mem->cv_setupNonNull)
 
 #define gammasv   (cvdiag_mem->di_gammasv)
 #define M         (cvdiag_mem->di_M)
@@ -112,26 +87,29 @@ static int CVDiagFree(CVodeMem cv_mem);
  * -----------------------------------------------------------------
  */
 
-int CVDiag(void *cvode_mem)
+int CVDiag(void* cvode_mem)
 {
   CVodeMem cv_mem;
   CVDiagMem cvdiag_mem;
 
   /* Return immediately if cvode_mem is NULL */
-  if (cvode_mem == NULL) {
-    cvProcessError(NULL, CVDIAG_MEM_NULL, "CVDIAG", "CVDiag", MSGDG_CVMEM_NULL);
-    return(CVDIAG_MEM_NULL);
+  if (cvode_mem == NULL)
+  {
+    cvProcessError(NULL, CVDIAG_MEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_CVMEM_NULL);
+    return (CVDIAG_MEM_NULL);
   }
-  cv_mem = (CVodeMem) cvode_mem;
+  cv_mem = (CVodeMem)cvode_mem;
 
   /* Check if N_VCompare and N_VInvTest are present */
-  if(vec_tmpl->ops->nvcompare == NULL ||
-     vec_tmpl->ops->nvinvtest == NULL) {
-    cvProcessError(cv_mem, CVDIAG_ILL_INPUT, "CVDIAG", "CVDiag", MSGDG_BAD_NVECTOR);
-    return(CVDIAG_ILL_INPUT);
+  if (vec_tmpl->ops->nvcompare == NULL || vec_tmpl->ops->nvinvtest == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_ILL_INPUT, __LINE__, __func__, __FILE__,
+                   MSGDG_BAD_NVECTOR);
+    return (CVDIAG_ILL_INPUT);
   }
 
-  if (lfree != NULL) lfree(cv_mem);
+  if (lfree != NULL) { lfree(cv_mem); }
 
   /* Set four main function fields in cv_mem */
   linit  = CVDiagInit;
@@ -141,45 +119,55 @@ int CVDiag(void *cvode_mem)
 
   /* Get memory for CVDiagMemRec */
   cvdiag_mem = NULL;
-  cvdiag_mem = (CVDiagMem) malloc(sizeof(CVDiagMemRec));
-  if (cvdiag_mem == NULL) {
-    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, "CVDIAG", "CVDiag", MSGDG_MEM_FAIL);
-    return(CVDIAG_MEM_FAIL);
+  cvdiag_mem = (CVDiagMem)malloc(sizeof(CVDiagMemRec));
+  if (cvdiag_mem == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, __LINE__, __func__, __FILE__,
+                   MSGDG_MEM_FAIL);
+    return (CVDIAG_MEM_FAIL);
   }
 
   last_flag = CVDIAG_SUCCESS;
 
-
   /* Allocate memory for M, bit, and bitcomp */
 
   M = N_VClone(vec_tmpl);
-  if (M == NULL) {
-    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, "CVDIAG", "CVDiag", MSGDG_MEM_FAIL);
-    free(cvdiag_mem); cvdiag_mem = NULL;
-    return(CVDIAG_MEM_FAIL);
+  if (M == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, __LINE__, __func__, __FILE__,
+                   MSGDG_MEM_FAIL);
+    free(cvdiag_mem);
+    cvdiag_mem = NULL;
+    return (CVDIAG_MEM_FAIL);
   }
 
   bit = N_VClone(vec_tmpl);
-  if (bit == NULL) {
-    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, "CVDIAG", "CVDiag", MSGDG_MEM_FAIL);
+  if (bit == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, __LINE__, __func__, __FILE__,
+                   MSGDG_MEM_FAIL);
     N_VDestroy(M);
-    free(cvdiag_mem); cvdiag_mem = NULL;
-    return(CVDIAG_MEM_FAIL);
+    free(cvdiag_mem);
+    cvdiag_mem = NULL;
+    return (CVDIAG_MEM_FAIL);
   }
 
   bitcomp = N_VClone(vec_tmpl);
-  if (bitcomp == NULL) {
-    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, "CVDIAG", "CVDiag", MSGDG_MEM_FAIL);
+  if (bitcomp == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_MEM_FAIL, __LINE__, __func__, __FILE__,
+                   MSGDG_MEM_FAIL);
     N_VDestroy(M);
     N_VDestroy(bit);
-    free(cvdiag_mem); cvdiag_mem = NULL;
-    return(CVDIAG_MEM_FAIL);
+    free(cvdiag_mem);
+    cvdiag_mem = NULL;
+    return (CVDIAG_MEM_FAIL);
   }
 
   /* Attach linear solver memory to integrator memory */
   lmem = cvdiag_mem;
 
-  return(CVDIAG_SUCCESS);
+  return (CVDIAG_SUCCESS);
 }
 
 /*
@@ -188,21 +176,23 @@ int CVDiag(void *cvode_mem)
  * -----------------------------------------------------------------
  */
 
-int CVDiagGetWorkSpace(void *cvode_mem, long int *lenrwLS, long int *leniwLS)
+int CVDiagGetWorkSpace(void* cvode_mem, long int* lenrwLS, long int* leniwLS)
 {
   CVodeMem cv_mem;
 
   /* Return immediately if cvode_mem is NULL */
-  if (cvode_mem == NULL) {
-    cvProcessError(NULL, CVDIAG_MEM_NULL, "CVDIAG", "CVDiagGetWorkSpace", MSGDG_CVMEM_NULL);
-    return(CVDIAG_MEM_NULL);
+  if (cvode_mem == NULL)
+  {
+    cvProcessError(NULL, CVDIAG_MEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_CVMEM_NULL);
+    return (CVDIAG_MEM_NULL);
   }
-  cv_mem = (CVodeMem) cvode_mem;
+  cv_mem = (CVodeMem)cvode_mem;
 
-  *lenrwLS = 3*lrw1;
-  *leniwLS = 3*liw1;
+  *lenrwLS = 3 * lrw1;
+  *leniwLS = 3 * liw1;
 
-  return(CVDIAG_SUCCESS);
+  return (CVDIAG_SUCCESS);
 }
 
 /*
@@ -211,27 +201,31 @@ int CVDiagGetWorkSpace(void *cvode_mem, long int *lenrwLS, long int *leniwLS)
  * -----------------------------------------------------------------
  */
 
-int CVDiagGetNumRhsEvals(void *cvode_mem, long int *nfevalsLS)
+int CVDiagGetNumRhsEvals(void* cvode_mem, long int* nfevalsLS)
 {
   CVodeMem cv_mem;
   CVDiagMem cvdiag_mem;
 
   /* Return immediately if cvode_mem is NULL */
-  if (cvode_mem == NULL) {
-    cvProcessError(NULL, CVDIAG_MEM_NULL, "CVDIAG", "CVDiagGetNumRhsEvals", MSGDG_CVMEM_NULL);
-    return(CVDIAG_MEM_NULL);
+  if (cvode_mem == NULL)
+  {
+    cvProcessError(NULL, CVDIAG_MEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_CVMEM_NULL);
+    return (CVDIAG_MEM_NULL);
   }
-  cv_mem = (CVodeMem) cvode_mem;
+  cv_mem = (CVodeMem)cvode_mem;
 
-  if (lmem == NULL) {
-    cvProcessError(cv_mem, CVDIAG_LMEM_NULL, "CVDIAG", "CVDiagGetNumRhsEvals", MSGDG_LMEM_NULL);
-    return(CVDIAG_LMEM_NULL);
+  if (lmem == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_LMEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_LMEM_NULL);
+    return (CVDIAG_LMEM_NULL);
   }
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   *nfevalsLS = nfeDI;
 
-  return(CVDIAG_SUCCESS);
+  return (CVDIAG_SUCCESS);
 }
 
 /*
@@ -240,27 +234,31 @@ int CVDiagGetNumRhsEvals(void *cvode_mem, long int *nfevalsLS)
  * -----------------------------------------------------------------
  */
 
-int CVDiagGetLastFlag(void *cvode_mem, long int *flag)
+int CVDiagGetLastFlag(void* cvode_mem, long int* flag)
 {
   CVodeMem cv_mem;
   CVDiagMem cvdiag_mem;
 
   /* Return immediately if cvode_mem is NULL */
-  if (cvode_mem == NULL) {
-    cvProcessError(NULL, CVDIAG_MEM_NULL, "CVDIAG", "CVDiagGetLastFlag", MSGDG_CVMEM_NULL);
-    return(CVDIAG_MEM_NULL);
+  if (cvode_mem == NULL)
+  {
+    cvProcessError(NULL, CVDIAG_MEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_CVMEM_NULL);
+    return (CVDIAG_MEM_NULL);
   }
-  cv_mem = (CVodeMem) cvode_mem;
+  cv_mem = (CVodeMem)cvode_mem;
 
-  if (lmem == NULL) {
-    cvProcessError(cv_mem, CVDIAG_LMEM_NULL, "CVDIAG", "CVDiagGetLastFlag", MSGDG_LMEM_NULL);
-    return(CVDIAG_LMEM_NULL);
+  if (lmem == NULL)
+  {
+    cvProcessError(cv_mem, CVDIAG_LMEM_NULL, __LINE__, __func__, __FILE__,
+                   MSGDG_LMEM_NULL);
+    return (CVDIAG_LMEM_NULL);
   }
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   *flag = last_flag;
 
-  return(CVDIAG_SUCCESS);
+  return (CVDIAG_SUCCESS);
 }
 
 /*
@@ -269,42 +267,26 @@ int CVDiagGetLastFlag(void *cvode_mem, long int *flag)
  * -----------------------------------------------------------------
  */
 
-char *CVDiagGetReturnFlagName(long int flag)
+char* CVDiagGetReturnFlagName(long int flag)
 {
-  char *name;
+  char* name;
 
-  name = (char *)malloc(30*sizeof(char));
+  name = (char*)malloc(30 * sizeof(char));
 
-  switch(flag) {
-  case CVDIAG_SUCCESS:
-    sprintf(name,"CVDIAG_SUCCESS");
-    break;
-  case CVDIAG_MEM_NULL:
-    sprintf(name,"CVDIAG_MEM_NULL");
-    break;
-  case CVDIAG_LMEM_NULL:
-    sprintf(name,"CVDIAG_LMEM_NULL");
-    break;
-  case CVDIAG_ILL_INPUT:
-    sprintf(name,"CVDIAG_ILL_INPUT");
-    break;
-  case CVDIAG_MEM_FAIL:
-    sprintf(name,"CVDIAG_MEM_FAIL");
-    break;
-  case CVDIAG_INV_FAIL:
-    sprintf(name,"CVDIAG_INV_FAIL");
-    break;
-  case CVDIAG_RHSFUNC_UNRECVR:
-    sprintf(name,"CVDIAG_RHSFUNC_UNRECVR");
-    break;
-  case CVDIAG_RHSFUNC_RECVR:
-    sprintf(name,"CVDIAG_RHSFUNC_RECVR");
-    break;
-  default:
-    sprintf(name,"NONE");
+  switch (flag)
+  {
+  case CVDIAG_SUCCESS: sprintf(name, "CVDIAG_SUCCESS"); break;
+  case CVDIAG_MEM_NULL: sprintf(name, "CVDIAG_MEM_NULL"); break;
+  case CVDIAG_LMEM_NULL: sprintf(name, "CVDIAG_LMEM_NULL"); break;
+  case CVDIAG_ILL_INPUT: sprintf(name, "CVDIAG_ILL_INPUT"); break;
+  case CVDIAG_MEM_FAIL: sprintf(name, "CVDIAG_MEM_FAIL"); break;
+  case CVDIAG_INV_FAIL: sprintf(name, "CVDIAG_INV_FAIL"); break;
+  case CVDIAG_RHSFUNC_UNRECVR: sprintf(name, "CVDIAG_RHSFUNC_UNRECVR"); break;
+  case CVDIAG_RHSFUNC_RECVR: sprintf(name, "CVDIAG_RHSFUNC_RECVR"); break;
+  default: sprintf(name, "NONE");
   }
 
-  return(name);
+  return (name);
 }
 
 /*
@@ -320,12 +302,12 @@ static int CVDiagInit(CVodeMem cv_mem)
 {
   CVDiagMem cvdiag_mem;
 
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   nfeDI = 0;
 
   last_flag = CVDIAG_SUCCESS;
-  return(0);
+  return (0);
 }
 
 /*
@@ -338,17 +320,18 @@ static int CVDiagInit(CVodeMem cv_mem)
  * -----------------------------------------------------------------
  */
 
-static int CVDiagSetup(CVodeMem cv_mem, int convfail, N_Vector ypred,
-                       N_Vector fpred, booleantype *jcurPtr, N_Vector vtemp1,
-                       N_Vector vtemp2, N_Vector vtemp3)
+static int CVDiagSetup(CVodeMem cv_mem, SUNDIALS_MAYBE_UNUSED int convfail,
+                       N_Vector ypred, N_Vector fpred, sunbooleantype* jcurPtr,
+                       N_Vector vtemp1, N_Vector vtemp2,
+                       SUNDIALS_MAYBE_UNUSED N_Vector vtemp3)
 {
-  realtype r;
+  sunrealtype r;
   N_Vector ftemp, y;
-  booleantype invOK;
+  sunbooleantype invOK;
   CVDiagMem cvdiag_mem;
   int retval;
 
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   /* Rename work vectors for use as temporary values of y and f */
   ftemp = vtemp1;
@@ -371,14 +354,17 @@ static int CVDiagSetup(CVodeMem cv_mem, int convfail, N_Vector ypred,
   /* Evaluate f at perturbed y */
   retval = f(tn, y, M, cv_mem->cv_user_data);
   nfeDI++;
-  if (retval < 0) {
-    cvProcessError(cv_mem, CVDIAG_RHSFUNC_UNRECVR, "CVDIAG", "CVDiagSetup", MSGDG_RHSFUNC_FAILED);
+  if (retval < 0)
+  {
+    cvProcessError(cv_mem, CVDIAG_RHSFUNC_UNRECVR, __LINE__, __func__, __FILE__,
+                   MSGDG_RHSFUNC_FAILED);
     last_flag = CVDIAG_RHSFUNC_UNRECVR;
-    return(-1);
+    return (-1);
   }
-  if (retval > 0) {
+  if (retval > 0)
+  {
     last_flag = CVDIAG_RHSFUNC_RECVR;
-    return(1);
+    return (1);
   }
 
   /* Construct M = I - gamma*J with J = diag(deltaf_i/deltay_i) */
@@ -405,16 +391,17 @@ static int CVDiagSetup(CVodeMem cv_mem, int convfail, N_Vector ypred,
 
   /* Invert M with test for zero components */
   invOK = N_VInvTest(M, M);
-  if (!invOK) {
+  if (!invOK)
+  {
     last_flag = CVDIAG_INV_FAIL;
-    return(1);
+    return (1);
   }
 
   /* Set jcur = SUNTRUE, save gamma in gammasv, and return */
-  *jcurPtr = SUNTRUE;
-  gammasv = gamma;
+  *jcurPtr  = SUNTRUE;
+  gammasv   = gamma;
   last_flag = CVDIAG_SUCCESS;
-  return(0);
+  return (0);
 }
 
 /*
@@ -426,24 +413,24 @@ static int CVDiagSetup(CVodeMem cv_mem, int convfail, N_Vector ypred,
  * -----------------------------------------------------------------
  */
 
-static int CVDiagSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
-                       N_Vector ycur, N_Vector fcur)
+static int CVDiagSolve(CVodeMem cv_mem, N_Vector b,
+                       SUNDIALS_MAYBE_UNUSED N_Vector weight,
+                       SUNDIALS_MAYBE_UNUSED N_Vector ycur,
+                       SUNDIALS_MAYBE_UNUSED N_Vector fcur)
 {
-  booleantype invOK;
-  realtype r;
+  sunbooleantype invOK;
+  sunrealtype r;
   CVDiagMem cvdiag_mem;
 
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   /* If gamma has changed, update factor in M, and save gamma value */
 
-  if (gammasv != gamma) {
+  if (gammasv != gamma)
+  {
     r = gamma / gammasv;
 #ifdef SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS
-    if (cv_mem->cv_usefused)
-    {
-      cvDiagSolve_updateM(r, M);
-    }
+    if (cv_mem->cv_usefused) { cvDiagSolve_updateM(r, M); }
     else
 #endif
     {
@@ -453,7 +440,8 @@ static int CVDiagSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
       N_VAddConst(M, ONE, M);
     }
     invOK = N_VInvTest(M, M);
-    if (!invOK) {
+    if (!invOK)
+    {
       last_flag = CVDIAG_INV_FAIL;
       return (1);
     }
@@ -464,7 +452,7 @@ static int CVDiagSolve(CVodeMem cv_mem, N_Vector b, N_Vector weight,
   N_VProd(b, M, b);
 
   last_flag = CVDIAG_SUCCESS;
-  return(0);
+  return (0);
 }
 
 /*
@@ -479,7 +467,7 @@ static int CVDiagFree(CVodeMem cv_mem)
 {
   CVDiagMem cvdiag_mem;
 
-  cvdiag_mem = (CVDiagMem) lmem;
+  cvdiag_mem = (CVDiagMem)lmem;
 
   N_VDestroy(M);
   N_VDestroy(bit);
@@ -487,5 +475,5 @@ static int CVDiagFree(CVodeMem cv_mem)
   free(cvdiag_mem);
   cv_mem->cv_lmem = NULL;
 
-  return(0);
+  return (0);
 }
