@@ -4,7 +4,7 @@
  *                Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -20,10 +20,10 @@
 #define _KINBBDPRE_IMPL_H
 
 #include <kinsol/kinsol_bbdpre.h>
-#include <sunmatrix/sunmatrix_band.h>
 #include <sunlinsol/sunlinsol_band.h>
+#include <sunmatrix/sunmatrix_band.h>
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
@@ -31,15 +31,15 @@ extern "C" {
   Definition of KBBDData
   ------------------------------------------------------------------*/
 
-typedef struct KBBDPrecDataRec {
-
+typedef struct KBBDPrecDataRec
+{
   /* passed by user to KINBBDPrecAlloc, used by pset/psolve functions */
   sunindextype mudq, mldq, mukeep, mlkeep;
-  realtype rel_uu;  /* relative error for the Jacobian DQ routine */
+  sunrealtype rel_uu; /* relative error for the Jacobian DQ routine */
   KINBBDLocalFn gloc;
   KINBBDCommFn gcomm;
 
-  /* set by KINBBDPrecSetup and used by KINBBDPrecSetup and 
+  /* set by KINBBDPrecSetup and used by KINBBDPrecSetup and
      KINBBDPrecSolve functions */
   sunindextype n_local;
   SUNMatrix PP;
@@ -56,9 +56,9 @@ typedef struct KBBDPrecDataRec {
   long int nge;
 
   /* pointer to KINSol memory */
-  void *kin_mem;
+  void* kin_mem;
 
-} *KBBDPrecData;
+}* KBBDPrecData;
 
 /*
  *-----------------------------------------------------------------
@@ -66,14 +66,18 @@ typedef struct KBBDPrecDataRec {
  *-----------------------------------------------------------------
  */
 
-#define MSGBBD_MEM_NULL    "KINSOL Memory is NULL."
-#define MSGBBD_LMEM_NULL   "Linear solver memory is NULL. One of the SPILS linear solvers must be attached."
+#define MSGBBD_MEM_NULL "KINSOL Memory is NULL."
+#define MSGBBD_LMEM_NULL                                                   \
+  "Linear solver memory is NULL. One of the SPILS linear solvers must be " \
+  "attached."
 #define MSGBBD_MEM_FAIL    "A memory request failed."
 #define MSGBBD_BAD_NVECTOR "A required vector operation is not implemented."
 #define MSGBBD_SUNMAT_FAIL "An error arose from a SUNBandMatrix routine."
 #define MSGBBD_SUNLS_FAIL  "An error arose from a SUNBandLinearSolver routine."
-#define MSGBBD_PMEM_NULL   "BBD peconditioner memory is NULL. IDABBDPrecInit must be called."
-#define MSGBBD_FUNC_FAILED "The gloc or gcomm routine failed in an unrecoverable manner."
+#define MSGBBD_PMEM_NULL \
+  "BBD peconditioner memory is NULL. IDABBDPrecInit must be called."
+#define MSGBBD_FUNC_FAILED \
+  "The gloc or gcomm routine failed in an unrecoverable manner."
 
 #ifdef __cplusplus
 }
