@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -18,14 +18,17 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <sunmatrix/sunmatrix_slunrloc.h>
-#include <sunlinsol/sunlinsol_superludist.h>
-#include <sundials/sundials_math.h>
 #include <superlu_ddefs.h>
 
-#define ZERO      RCONST(0.0)
-#define ONE       RCONST(1.0)
-#define TWO       RCONST(2.0)
+#include <sundials/sundials_math.h>
+#include <sunlinsol/sunlinsol_superludist.h>
+#include <sunmatrix/sunmatrix_slunrloc.h>
+
+#include "sundials_macros.h"
+
+#define ZERO SUN_RCONST(0.0)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
 
 /*
  * -----------------------------------------------------------------
@@ -33,17 +36,17 @@
  * -----------------------------------------------------------------
  */
 
-#define SLUDIST_CONTENT(S)    ( (SUNLinearSolverContent_SuperLUDIST)(S->content) )
-#define SLU_FIRSTFACTORIZE(S) ( SLUDIST_CONTENT(S)->first_factorize )
-#define SLU_BERR(S)           ( SLUDIST_CONTENT(S)->berr )
-#define SLU_GRID(S)           ( SLUDIST_CONTENT(S)->grid )
-#define SLU_LASTFLAG(S)       ( SLUDIST_CONTENT(S)->last_flag )
-#define SLU_LU(S)             ( SLUDIST_CONTENT(S)->lu )
-#define SLU_OPTIONS(S)        ( SLUDIST_CONTENT(S)->options )
-#define SLU_SCALEPERM(S)      ( SLUDIST_CONTENT(S)->scaleperm )
-#define SLU_SOLVESTRUCT(S)    ( SLUDIST_CONTENT(S)->solve )
-#define SLU_STAT(S)           ( SLUDIST_CONTENT(S)->stat )
-#define SLU_SIZE(S)           ( SLUDIST_CONTENT(S)->N )
+#define SLUDIST_CONTENT(S)    ((SUNLinearSolverContent_SuperLUDIST)(S->content))
+#define SLU_FIRSTFACTORIZE(S) (SLUDIST_CONTENT(S)->first_factorize)
+#define SLU_BERR(S)           (SLUDIST_CONTENT(S)->berr)
+#define SLU_GRID(S)           (SLUDIST_CONTENT(S)->grid)
+#define SLU_LASTFLAG(S)       (SLUDIST_CONTENT(S)->last_flag)
+#define SLU_LU(S)             (SLUDIST_CONTENT(S)->lu)
+#define SLU_OPTIONS(S)        (SLUDIST_CONTENT(S)->options)
+#define SLU_SCALEPERM(S)      (SLUDIST_CONTENT(S)->scaleperm)
+#define SLU_SOLVESTRUCT(S)    (SLUDIST_CONTENT(S)->solve)
+#define SLU_STAT(S)           (SLUDIST_CONTENT(S)->stat)
+#define SLU_SIZE(S)           (SLUDIST_CONTENT(S)->N)
 
 /*
  * ----------------------------------------------------------------------------
@@ -51,34 +54,38 @@
  * ----------------------------------------------------------------------------
  */
 
-SUNLinearSolver SUNLinSol_SuperLUDIST(N_Vector y, SUNMatrix A, gridinfo_t *grid,
-                                      xLUstruct_t *lu, xScalePermstruct_t *scaleperm,
-                                      xSOLVEstruct_t *solve, SuperLUStat_t *stat,
-                                      superlu_dist_options_t *options, SUNContext sunctx)
+SUNLinearSolver SUNLinSol_SuperLUDIST(N_Vector y, SUNMatrix A, gridinfo_t* grid,
+                                      xLUstruct_t* lu,
+                                      xScalePermstruct_t* scaleperm,
+                                      xSOLVEstruct_t* solve, SuperLUStat_t* stat,
+                                      superlu_dist_options_t* options,
+                                      SUNContext sunctx)
 {
   SUNLinearSolver S;
   SUNLinearSolverContent_SuperLUDIST content;
-  SuperMatrix *Asuper;
-  NRformat_loc *Astore;
+  SuperMatrix* Asuper;
+  NRformat_loc* Astore;
 
   /* Check that required arguments are not NULL */
   if (y == NULL || A == NULL || grid == NULL || lu == NULL ||
       scaleperm == NULL || solve == NULL || stat == NULL || options == NULL)
-    return(NULL);
+  {
+    return (NULL);
+  }
 
   /* Check compatibility with supplied SUNMatrix and N_Vector */
-  if (SUNMatGetID(A) != SUNMATRIX_SLUNRLOC) return(NULL);
+  if (SUNMatGetID(A) != SUNMATRIX_SLUNRLOC) { return (NULL); }
 
   Asuper = SUNMatrix_SLUNRloc_SuperMatrix(A);
-  Astore = (NRformat_loc *) Asuper->Store;
+  Astore = (NRformat_loc*)Asuper->Store;
 
   /* Check that the matrix is square */
-  if (Asuper->nrow != Asuper->ncol) return(NULL);
+  if (Asuper->nrow != Asuper->ncol) { return (NULL); }
 
   /* Create an empty linear solver */
   S = NULL;
   S = SUNLinSolNewEmpty(sunctx);
-  if (S == NULL) return(NULL);
+  if (S == NULL) { return (NULL); }
 
   /* Attach operations */
   S->ops->gettype    = SUNLinSolGetType_SuperLUDIST;
@@ -92,8 +99,12 @@ SUNLinearSolver SUNLinSol_SuperLUDIST(N_Vector y, SUNMatrix A, gridinfo_t *grid,
 
   /* Create content */
   content = NULL;
-  content = (SUNLinearSolverContent_SuperLUDIST) malloc(sizeof *content);
-  if (content == NULL) { SUNLinSolFree(S); return(NULL); }
+  content = (SUNLinearSolverContent_SuperLUDIST)malloc(sizeof *content);
+  if (content == NULL)
+  {
+    SUNLinSolFree(S);
+    return (NULL);
+  }
 
   /* Attach content */
   S->content = content;
@@ -109,7 +120,7 @@ SUNLinearSolver SUNLinSol_SuperLUDIST(N_Vector y, SUNMatrix A, gridinfo_t *grid,
   content->berr      = ZERO;
   content->last_flag = 0;
 
-  return(S);
+  return (S);
 }
 
 /*
@@ -118,39 +129,39 @@ SUNLinearSolver SUNLinSol_SuperLUDIST(N_Vector y, SUNMatrix A, gridinfo_t *grid,
  * -----------------------------------------------------------------
  */
 
-realtype SUNLinSol_SuperLUDIST_GetBerr(SUNLinearSolver LS)
+sunrealtype SUNLinSol_SuperLUDIST_GetBerr(SUNLinearSolver LS)
 {
-  return(SLU_BERR(LS));
+  return (SLU_BERR(LS));
 }
 
 gridinfo_t* SUNLinSol_SuperLUDIST_GetGridinfo(SUNLinearSolver LS)
 {
-  return(SLU_GRID(LS));
+  return (SLU_GRID(LS));
 }
 
 xLUstruct_t* SUNLinSol_SuperLUDIST_GetLUstruct(SUNLinearSolver LS)
 {
-  return(SLU_LU(LS));
+  return (SLU_LU(LS));
 }
 
 superlu_dist_options_t* SUNLinSol_SuperLUDIST_GetSuperLUOptions(SUNLinearSolver LS)
 {
-  return(SLU_OPTIONS(LS));
+  return (SLU_OPTIONS(LS));
 }
 
 xScalePermstruct_t* SUNLinSol_SuperLUDIST_GetScalePermstruct(SUNLinearSolver LS)
 {
-  return(SLU_SCALEPERM(LS));
+  return (SLU_SCALEPERM(LS));
 }
 
 xSOLVEstruct_t* SUNLinSol_SuperLUDIST_GetSOLVEstruct(SUNLinearSolver LS)
 {
-  return(SLU_SOLVESTRUCT(LS));
+  return (SLU_SOLVESTRUCT(LS));
 }
 
 SuperLUStat_t* SUNLinSol_SuperLUDIST_GetSuperLUStat(SUNLinearSolver LS)
 {
-  return(SLU_STAT(LS));
+  return (SLU_STAT(LS));
 }
 
 /*
@@ -159,66 +170,75 @@ SuperLUStat_t* SUNLinSol_SuperLUDIST_GetSuperLUStat(SUNLinearSolver LS)
  * -----------------------------------------------------------------
  */
 
-SUNLinearSolver_Type SUNLinSolGetType_SuperLUDIST(SUNLinearSolver S)
+SUNLinearSolver_Type SUNLinSolGetType_SuperLUDIST(
+  SUNDIALS_MAYBE_UNUSED SUNLinearSolver S)
 {
-  return(SUNLINEARSOLVER_DIRECT);
+  return (SUNLINEARSOLVER_DIRECT);
 }
 
-SUNLinearSolver_ID SUNLinSolGetID_SuperLUDIST(SUNLinearSolver S)
+SUNLinearSolver_ID SUNLinSolGetID_SuperLUDIST(SUNDIALS_MAYBE_UNUSED SUNLinearSolver S)
 {
-  return(SUNLINEARSOLVER_SUPERLUDIST);
+  return (SUNLINEARSOLVER_SUPERLUDIST);
 }
 
-int SUNLinSolInitialize_SuperLUDIST(SUNLinearSolver S)
+SUNErrCode SUNLinSolInitialize_SuperLUDIST(SUNLinearSolver S)
 {
   SLU_FIRSTFACTORIZE(S) = SUNTRUE;
 
-  SLU_LASTFLAG(S) = SUNLS_SUCCESS;
-  return(SLU_LASTFLAG(S));
+  SLU_LASTFLAG(S) = SUN_SUCCESS;
+  return (SLU_LASTFLAG(S));
 }
 
-int SUNLinSolSetup_SuperLUDIST(SUNLinearSolver S, SUNMatrix A)
+int SUNLinSolSetup_SuperLUDIST(SUNLinearSolver S,
+                               SUNDIALS_MAYBE_UNUSED SUNMatrix A)
 {
-  if (SLU_FIRSTFACTORIZE(S)) {
+  if (SLU_FIRSTFACTORIZE(S))
+  {
     /* Force factorization on next solve. */
     SLU_OPTIONS(S)->Fact = DOFACT;
 
     /* if the solve struct was already initialized, we need to
        finalize the last solve to avoid leaking memory */
-    if (SLU_OPTIONS(S)->SolveInitialized == YES) {
+    if (SLU_OPTIONS(S)->SolveInitialized == YES)
+    {
       xDestroy_LU(SLU_SIZE(S), SLU_GRID(S), SLU_LU(S));
       dSolveFinalize(SLU_OPTIONS(S), SLU_SOLVESTRUCT(S));
     }
-  } else {
+  }
+  else
+  {
     /* Force factorization on next solve, but reuse column permutation */
     SLU_OPTIONS(S)->Fact = SamePattern;
   }
 
-  SLU_LASTFLAG(S) = SUNLS_SUCCESS;
-  return(SLU_LASTFLAG(S));
+  SLU_LASTFLAG(S) = SUN_SUCCESS;
+  return (SLU_LASTFLAG(S));
 }
 
-int SUNLinSolSolve_SuperLUDIST(SUNLinearSolver S, SUNMatrix A,
-                               N_Vector x, N_Vector b, realtype tol)
+int SUNLinSolSolve_SuperLUDIST(SUNLinearSolver S, SUNMatrix A, N_Vector x,
+                               N_Vector b, SUNDIALS_MAYBE_UNUSED sunrealtype tol)
 {
   int retval;
-  realtype *xdata;
-  SuperMatrix *Asuper;
-  NRformat_loc *Astore;
+  sunrealtype* xdata;
+  SuperMatrix* Asuper;
+  NRformat_loc* Astore;
 
   if ((S == NULL) || (A == NULL) || (x == NULL) || (b == NULL))
-    return(SUNLS_MEM_NULL);
+  {
+    return SUN_ERR_ARG_CORRUPT;
+  }
 
   Asuper = SUNMatrix_SLUNRloc_SuperMatrix(A);
-  Astore = (NRformat_loc *) Asuper->Store;
+  Astore = (NRformat_loc*)Asuper->Store;
 
   /* Copy b into x, and use xdata with SuperLU-DIST because
      SuperLU reuses b to store the solution vector. */
   N_VScale(ONE, b, x);
   xdata = N_VGetArrayPointer(x);
-  if (xdata == NULL) {
-    SLU_LASTFLAG(S) = SUNLS_MEM_FAIL;
-    return(SLU_LASTFLAG(S));
+  if (xdata == NULL)
+  {
+    SLU_LASTFLAG(S) = SUN_ERR_MEM_FAIL;
+    return (SLU_LASTFLAG(S));
   }
 
   /* Call SuperLU-DIST to solve the linear system */
@@ -226,34 +246,35 @@ int SUNLinSolSolve_SuperLUDIST(SUNLinearSolver S, SUNMatrix A,
           SLU_GRID(S), SLU_LU(S), SLU_SOLVESTRUCT(S), &SLU_BERR(S), SLU_STAT(S),
           &retval);
 
-  if (retval != 0) {
+  if (retval != 0)
+  {
     /* retval should never be < 0, and if it is > than ncol it means a memory
        allocation error occured. If 0 < retval <= ncol, then U is singular and
        the solve couldn't be completed. */
     if (retval < 0 || retval > Asuper->ncol)
-      SLU_LASTFLAG(S) = SUNLS_PACKAGE_FAIL_UNREC;
-    else
-      SLU_LASTFLAG(S) = SUNLS_PACKAGE_FAIL_REC;
-    return(SLU_LASTFLAG(S));
+    {
+      SLU_LASTFLAG(S) = SUN_ERR_EXT_FAIL;
+    }
+    else { SLU_LASTFLAG(S) = SUNLS_PACKAGE_FAIL_REC; }
+    return (SLU_LASTFLAG(S));
   }
 
   /* Tell SuperLU-DIST that A is already factored so do not factorize */
   SLU_OPTIONS(S)->Fact = FACTORED;
 
-  SLU_LASTFLAG(S) = SUNLS_SUCCESS;
-  return(SLU_LASTFLAG(S));
+  SLU_LASTFLAG(S) = SUN_SUCCESS;
+  return (SLU_LASTFLAG(S));
 }
 
 sunindextype SUNLinSolLastFlag_SuperLUDIST(SUNLinearSolver S)
 {
-  if (S == NULL) return(-1);
-  return(SLU_LASTFLAG(S));
+  return (SLU_LASTFLAG(S));
 }
 
-int SUNLinSolFree_SuperLUDIST(SUNLinearSolver S)
+SUNErrCode SUNLinSolFree_SuperLUDIST(SUNLinearSolver S)
 {
   /* return with success if already freed */
-  if (S == NULL) return(SUNLS_SUCCESS);
+  if (S == NULL) { return SUN_SUCCESS; }
 
   /* Call SuperLU DIST destroy/finalize routines,
      but don't free the sturctures themselves - that is the user's job */
@@ -261,13 +282,15 @@ int SUNLinSolFree_SuperLUDIST(SUNLinearSolver S)
   dSolveFinalize(SLU_OPTIONS(S), SLU_SOLVESTRUCT(S));
 
   /* free content structure */
-  if (S->content) {
+  if (S->content)
+  {
     free(S->content);
     S->content = NULL;
   }
 
   /* free ops structure */
-  if (S->ops) {
+  if (S->ops)
+  {
     free(S->ops);
     S->ops = NULL;
   }
@@ -276,11 +299,11 @@ int SUNLinSolFree_SuperLUDIST(SUNLinearSolver S)
   free(S);
   S = NULL;
 
-  return(SUNLS_SUCCESS);
+  return SUN_SUCCESS;
 }
 
-int SUNLinSolSpace_SuperLUDIST(SUNLinearSolver S, long int *leniwLS,
-                               long int *lenrwLS)
+SUNErrCode SUNLinSolSpace_SuperLUDIST(SUNDIALS_MAYBE_UNUSED SUNLinearSolver S,
+                                      long int* leniwLS, long int* lenrwLS)
 {
   /* since the SuperLU_DIST structures are opaque objects, we
      omit those from these results */
@@ -288,5 +311,5 @@ int SUNLinSolSpace_SuperLUDIST(SUNLinearSolver S, long int *leniwLS,
   *leniwLS = 2; /* last_flag, N */
   *lenrwLS = 1; /* berr */
 
-  return(SUNLS_SUCCESS);
+  return SUN_SUCCESS;
 }
