@@ -3,7 +3,7 @@
 # Programmer(s): David J. Gardner @ LLNL
 # -----------------------------------------------------------------------------
 # SUNDIALS Copyright Start
-# Copyright (c) 2002-2022, Lawrence Livermore National Security
+# Copyright (c) 2002-2024, Lawrence Livermore National Security
 # and Southern Methodist University.
 # All rights reserved.
 #
@@ -49,6 +49,11 @@ def main():
                                       '''Options for setting the C, C++,
                                       Fortran, and CUDA compiler and flags.''')
 
+    # Build type
+    add_arg(group, '--build-type', 'CMAKE_BUILD_TYPE', 'CMAKE_BUILD_TYPE',
+            'RelWithDebInfo', 'STRING',
+            'CMake build type (Debug, RelWithDebInfo, Release)')
+
     # C compiler
     add_arg(group, '--c-compiler', 'CC', 'CMAKE_C_COMPILER', None, 'FILEPATH',
             'C compiler')
@@ -220,15 +225,17 @@ def main():
             'SUNDIALS_LOGGING_LEVEL', '0', 'STRING',
             'logging', choices=['0', '1', '2', '3', '4', '5'])
 
-    add_arg(group, '--logging-mpi', 'SUNDIALS_LOGGING_ENABLE_MPI',
-            'SUNDIALS_LOGGING_ENABLE_MPI', 'OFF', 'BOOL',
-            'MPI-aware logging')
-
     # fused kernels
     add_arg(group, '--fused-kernels', 'SUNDIALS_FUSED_KERNELS',
             'SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS', 'OFF', 'BOOL',
             'package fused kernels')
 
+    # error checks
+    add_arg(group, '--enable-error-checks', 'SUNDIALS_ENABLE_ERROR_CHECKS',
+            'SUNDIALS_ENABLE_ERROR_CHECKS', 'OFF', 'BOOL',
+            'enable error checks')
+
+
     # -----------
     # Interfaces
     # -----------
@@ -559,6 +566,10 @@ def main():
             'SUNDIALS_TEST_UNITTESTS', 'OFF', 'BOOL',
             'SUNDIALS unit tests')
 
+    add_arg(group, '--no-gtest', 'SUNDIALS_TEST_ENABLE_GTEST',
+            'SUNDIALS_TEST_ENABLE_GTEST', 'ON', 'BOOL',
+            'SUNDIALS GTest unit tests')
+
     # test output directory
     add_arg(group, '--test-output-dir', 'SUNDIALS_TEST_OUTPUT_DIR',
             'SUNDIALS_TEST_OUTPUT_DIR', None, 'PATH',
